#!/usr/bin/perl -w
#
# synonoTree.pl v2.1
# Last modified March 16, 2005 14:03
# (c) Olaf R.P. Bininda-Emonds
#
# Input:
#   1) A nexus-formatted tree file
#	2) A tab-delimited text file (in the format old name <tab> new name) containing a paired list of synonyms (as needed)
#	3) A file of valid taxon names, listed one per line (optional)
#
# Output:
#	Either:
#		1) mismatch.txt: Contains a list of species not found in reference taxonomy, whether these species occur in the
#		   source trees or the paired synonymy list.
#		2) inputfile_nex.nex: A nexus-formatted tree file, with species synonymized according to input files #2 and #3,
#		   duplicated instances of a species removed, and all permutations of a source tree with paraphyletic species
#		   represented once only.
#
# Usage: synonoTree.pl -t<filename> [-d] [-i<name,name>] [-l<filename>] [-s<filename>] [-v] [-h]
#   options: -t<filename> = file containing trees in NEXUS format
#			 -d = autodelete taxa not in reference taxonomy
#            -i<Name[,Name]> = names of mammalian orders to restrict taxonomy list
#                            (Multiple names must be seaprated by commas without spaces)
#            -l = reference taxonomy file, with valid names listed one per line
#            -s = tab-delimited file (old name <tab> new name) containing paired list of species synonyms;
#				  when used as the new name, xxx means that species will be deleted from source tree
#			 -v = verbose mode (not recommended!)
#            -h = print this message and quit

use strict;

# Set defaults and clear global variables
	# I/O parameters
		my ($treeRead, $treeWrite);	

	# Taxonomy parameters
		my ($refTax, $synList);
		my (%reftaxNames, %synName, %synonym);
			$reftaxNames{OG} = 1;	# Always recognize fictitious outgroup
			$reftaxNames{xxx} = 1;	# Always recognize
		my @wrongNameList;
		my $paraFlag;
		my $autoDelete = 0;
		my @inGroup;

	# Input tree variables
		my (@allTrees, @treeName);
		my (%treeDescription, %treeName);
		my @mismatchTemp;

	# Cleaning parameters
		my (@treeSpecies, @delPositions);
	
	# Permutation parameters
		my $compType = "ref";
		my (@paraList, %para, %presentTree);
#		my @acceptList;
	
	# Miscellaneous parameters
		my $verbose = 0;
		my $debug = 0;

for (my $i = 0; $i <= $#ARGV; $i++)
	{
	if ($ARGV[$i] =~ /-t([\w+\.?\w+?]*)/)
		{
		$treeRead = $1;
		($treeWrite) = split(/\./,$treeRead,0);
			$treeWrite .= "_new.tre";
		}
	elsif ($ARGV[$i] eq "-d")
		{
		$autoDelete = 1;
		}
	elsif ($ARGV[$i] =~ /-i(\S+)/)
		{
		@inGroup = split(/,/,$1);
		}
	elsif ($ARGV[$i] =~ /-s([\w+\.?\w+?]*)/)
		{
		$synList = $1;
		}
	elsif ($ARGV[$i] =~ /-l([\w+\.?\w+?]*)/)
		{
		$refTax = $1;
		}
	elsif ($ARGV[$i] =~ /-v/)
		{
		$verbose = 1;
		}
	elsif ($ARGV[$i] =~ /-x/)
		{
		$debug = $verbose = 1;
		}
	elsif ($ARGV[$i] eq "-h")
		{
		print "Usage: synonoTree.pl -t<filename> [-d] [-i<name,name>] [-l<filename>] [-s<filename>] [-v] [-h]\n";
		print "Options: -t<filename> = file containing trees in NEXUS format\n";
		print "         -d = autodelete taxa not in reference taxonomy\n";
		print "         -i<Name[,Name]> = names of mammalian orders to restrict taxonomy list\n";
		print "                           (Multiple names must be seaprated by commas without spaces)\n";
		print "         -l = reference taxonomy file, with valid names listed one per line\n";
		print "         -s = tab-delimited file (old name <tab> new name) containing paired list of species synonyms;\n";
		print "              when used as the new name, xxx means that species will be deleted from source tree\n";
		print "         -v = verbose mode (not recommended!)\n";
		print "         -h = print this message and quit\n";
		exit(0);
		}
	else
		{
		print "Don't understand argument: $ARGV[$i]\n";
		print "Usage: synonoTree.pl -t<filename> [-d] [-i<name,name>] [-l<filename>] [-s<filename>] [-v] [-h]\n";
		exit(1); 
		}
	}
	
die "ERROR: Must specify name of nexus-formatted treefile.\n" if (not defined $treeRead);

if (not @inGroup)
	{
	@inGroup = qw(Monotremata
		Xenarthra
		Proboscidea
		Insectivora
		Scandentia
		Sirenia
		Chiroptera
		Primates
		Carnivora
		Cetacea
		Hyracoidea
		Rodentia
		Lagomorpha
		Didelphimorphia
		Dermoptera
		Perissodactyla
		Tubulidentata
		Paucituberculata
		Artiodactyla
		Pholidota
		Microbiotheria
		Macroscelidea
		Dasyuromorphia
		Peramelemorphia
		Notoryctemorphia
		Diprotodontia);
	}

# Get reference taxonomy
	if ($refTax)	# Read in user-input taxonomy list
		{
		setLineBreak($refTax);
		open (TAX, "<$refTax") or die "Cannot open reference taxonomy file, $refTax.\n";
			while (<TAX>)
				{
				next unless ($_);
				my $refSpecies = $_;
				chomp ($refSpecies);
				if ($refSpecies)
					{
					$refSpecies =~ s/\s+$//g;
					$refSpecies =~ s/\s/_/g;
					$reftaxNames{$refSpecies} = 1;
					}
				}
		close TAX;
		}
	else
		{
		WRread (@inGroup);		# Call subroutine to read in WR93 names
		}

# Read in synonymies from file as needed
	if ($synList)
		{
		setLineBreak($synList);
		open (REF, "<$synList") or die "Cannot open synonymy list, $synList\n";
			while (<REF>)
				{
				chomp;
				next unless ($_);
				my ($rightName, $wrongName);
				if ($synList eq "SpeciesSynonymID.txt")
					{
					next if ($_ =~ /^Genus/);
					my @lookupLine = split(/\t/);					
					$wrongName = join('_', $lookupLine[0], $lookupLine[1], $lookupLine[2]);
						$wrongName =~ s/_unspecified//ig;
					$rightName = $lookupLine[4];
						$rightName =~ s/\s+$//g;
						$rightName =~ s/\s+/_/g;
					}
				else
					{
					($wrongName, $rightName) = split(/\t/);
						$wrongName =~ s/\s+/_/g;
						$rightName =~ s/\s+/_/g;
					}

				if (defined $rightName and ($rightName eq "None" or $rightName eq "none" or $rightName eq "NONE" or $rightName eq "None_(extinct)" or $rightName =~ /_or_/))
					{
					$synonym{$wrongName} = "";
					}
				else
					{
					$synonym{$wrongName} = $rightName;
					}
				}
		close REF;
		}

# Read in source tree descriptions
	my $numTrees = 0;
	setLineBreak($treeRead);
	open (READ, "<$treeRead") or die "Cannot open source tree file, $treeRead.\n";
		while (<READ>)
			{
			next unless ($_);
			my $lineRead = $_;
			chomp ($lineRead);
			if ($lineRead =~ /=/ and $lineRead =~ /tree/i)
				{
				my ($header, $moreHeader, $sourceTree, $name);
				($header, $sourceTree) = split (/=/, $lineRead);		# Read in tree description, process, and clean up
					$header =~ s/\*//g;	# Remove asterisk denoting default tree
					$header =~ s/^\s//g;
						($moreHeader, $name) = split (/\s+/, $header);
					$sourceTree =~ s/;//g;
					$sourceTree =~ s/ \[&.\]//g;
					$sourceTree =~ s/:\d+\.?\d*//g;
					$sourceTree =~ s/\s//g;
					
					# Store source trees
						$numTrees++;
							$treeDescription{$numTrees} = $sourceTree;
							$treeName{$numTrees} = $name;
					
						push @allTrees, $sourceTree;
						push @treeName, $name;
	
				$sourceTree =~ s/\(//g;		# Process source tree further to derive taxon names
				$sourceTree =~ s/\)//g;
				my (@taxa) = split (/,/, $sourceTree);
				foreach my $species (@taxa)
					{
					$species =~ s/\s+/_/g;
					unless (defined $reftaxNames{$species})
						{
						if ($autoDelete or (not defined $synonym{$species} and $synList eq "SpeciesSynonymID.txt") or (defined $synonym{$species} and defined $reftaxNames{ $synonym{$species} }))	# Name explicitly recognized as being wrong
							{
							push @wrongNameList, $species;
							}
						else	# Name not recognized
							{
							push @mismatchTemp, $species;
							}
						}
					}
				}
			}
	close READ;

# Check if uncorrected mismatches exist
	my @mismatchList = duplStrip(@mismatchTemp);
	if (@mismatchList and not $autoDelete)	# Source trees contain unrecognized taxa; write to file and exit
		{
		open (MIS, ">mismatch.txt") or die "Cannot open mismatch.txt.\n";
		foreach my $name (@mismatchList)
			{
			print MIS "$name\t\n";
			}
		close MIS;
		print "NOTE: Species names found in source trees that are not in reference taxonomy. Written to file mismatch.txt.\n";
		exit(0);
		}

# Synonomize and clean trees
	my $treeCount = 0;
	open (WRITE, ">$treeWrite") or die "Cannot write to new source tree file, $treeWrite.\n";
		print WRITE "#NEXUS\n\nbegin trees;\n";
	open (PARA, ">paraSpecies.txt") or die "Cannot write to file, paraSpecies.txt.\n";
		print PARA "Tree name\tParaphyletic species\n";
	for (my $treeID = 1; $treeID <= $numTrees; $treeID++)	# Synonymize names on tree (if necessary)
		{
		my $sourceTree = $treeDescription{$treeID};

		print "\nTree name: $treeName{$treeID}\n" if ($verbose);
		print "\tOriginal tree: $sourceTree\n" if ($verbose);

		foreach my $wrongName (@wrongNameList)
			{
			if ($autoDelete or (defined $synonym{$wrongName} and $synonym{$wrongName} eq "xxx") or (not defined $synonym{$wrongName} and $synList eq "SpeciesSynonymID.txt"))
				{
				$sourceTree =~ s/$wrongName,/,/g;
				$sourceTree =~ s/$wrongName\(/\(/g;
				$sourceTree =~ s/$wrongName\)/\)/g;
				$sourceTree =~ s/$wrongName:/:/g;
				}
			else
				{
				$sourceTree =~ s/$wrongName,/$synonym{$wrongName},/g;
				$sourceTree =~ s/$wrongName\(/$synonym{$wrongName}\(/g;
				$sourceTree =~ s/$wrongName\)/$synonym{$wrongName}\)/g;
				$sourceTree =~ s/$wrongName:/$synonym{$wrongName}:/g;
				}
			}
		print "\n\tSynonymized: $sourceTree\n" if ($verbose);
		($sourceTree) = dupRemove($sourceTree);
		print "\n\tCleaned: $sourceTree\n" if ($verbose);
		
		next if (($sourceTree =~ tr/(//) < 2);	# Tree synonymized to a bush; no point in outputting
		
		# Count taxa on tree to identify non-monophyletic taxa	
			my $taxa = $sourceTree;
				$taxa =~ s/\)//g;
				$taxa =~ s/\(//g;
			my @taxonList = split(/,/, $taxa);
				next if (scalar(@taxonList) < 3);	# Tree synonymized to too few species; no point in outputting
	
			undef %presentTree;
			undef @paraList;
			undef %para;
			foreach my $taxon (@taxonList)
				{
				$presentTree{$taxon}++;
				if ($presentTree{$taxon} == 2)	# Taxon is not monophyletic
					{
					push @paraList, $taxon;
					$para{$taxon} = 1;
					}
				}
			if (@paraList)		# Tree contains non-monophyletic taxa
				{
				$paraFlag++;
				print PARA "$treeName{$treeID}\t";
				my $paraTree = $sourceTree;
				# Mark non-monophyletic species in tree description
					foreach my $species (@paraList)
						{
						print "\tparaSpecies: $species\n" if ($verbose);
						print PARA "$species ";
						$paraTree =~ s/$species/\*\*\*$species\*\*\*/g;
						}
					print PARA "\n";
					print WRITE "\t[tree $treeName{$treeID} = $paraTree;]\n";
	
				# Remove duplicated taxon names from list as preliminary step for dot plots
					my %dupl;
						my @allTaxa = grep(!$dupl{$_}++, @taxonList);
						@allTaxa = sort {$a cmp $b} @allTaxa; 
				
				paraPermutation ($treeName{$treeID}, $sourceTree);	# Output subtrees, where each paraphyletic taxon occurs only once
				}
			else # elsif (count of open parentheses > 1)
				{
				print WRITE "\ttree $treeName{$treeID} = $sourceTree;\n";
				}
			# else print tree in square parentheses
	
		$treeCount++;
		}
	print WRITE "end;\n";
	close WRITE;
	close PARA;

# Print summary of run
	if ($paraFlag)
		{
		print "Non-monophyletic species detected on $paraFlag tree";
		print "s" if ($paraFlag > 1);
		print ".\n\tSummary written to paraSpecies.txt.\n\tModified tree file written as $treeWrite.\n";
		}
	else
		{
		print "No non-monophyletic species detected on any trees.\n\tModified tree file written as $treeWrite.\n";
		}

exit(0);

### Subroutines used in program

sub duplStrip	# Subroutine to strip duplicate entries from an array
	{
	my @duplArray = @_;
	my %dupl;		#Remove duplicate taxa
		my @stripArray = grep(!$dupl{$_}++, @duplArray);
		@stripArray = sort {$a cmp $b} @stripArray;
	return @stripArray;
	}

sub dupRemove	# Subroutine to recursively remove duplicated taxa within a clade
	{
	my $workTree = shift;
	my $dupRemove = 1;
	until ($dupRemove == 0)
		{
		$dupRemove = 0;
		print "\t\twork($dupRemove): $workTree\n" if ($debug);
		my $iTree = $workTree;
		$workTree = "";
		my ($position, $CladeID, $CurrentClade) = (0, 0, 0);
		my (@ParentClade, $OldCurrent);
		my %presentCurrent;
		undef %presentTree;
		undef @treeSpecies;
		my $offset;
		
		while ($position < length($iTree))
			{
			$offset = 1;
			if (substr($iTree, $position, 1) eq "(")	# New clade; go one level deeper
				{
				$CladeID++;
				$ParentClade[$CladeID] = $CurrentClade;
				$CurrentClade = $CladeID;
				undef %presentCurrent;
				$workTree .= "(";
				}
			elsif (substr($iTree, $position, 1) eq ")")	# Clade finished; clean up and go up one level
				{
				$OldCurrent = $CurrentClade;
				$CurrentClade = $ParentClade[$OldCurrent];
				$workTree .= ")";
				print "$workTree\n" if ($debug);
				}
			elsif (substr($iTree, $position, 1) eq ",")
				{
				$workTree .= ",";
				}
			else	# Determine taxa in clade
				{
				until (substr($iTree, $position+$offset, 1) eq "(" or substr($iTree, $position+$offset, 1) eq ")" or substr($iTree, $position+$offset, 1) eq ",")
					{
					$offset++;
					}
				my $taxon = substr($iTree, $position, $offset);
				if (not $presentCurrent{$taxon}{$CurrentClade})	# Write first description of taxon in current clade
					{
					$presentTree{$taxon}++;
						if ($presentTree{$taxon} == 1)	# List all taxa on source tree
							{
							push @treeSpecies, $taxon;
							}
					$presentCurrent{$taxon}{$CurrentClade} = 1;
					$workTree .= "$taxon";
					}
				else
					{
					$dupRemove = 1;
					}
				$position += $offset-1;
				}
			$position++;
			}
		print "\t\tpostwork($dupRemove): $workTree\n" if ($debug);
		$workTree = cleanTree($workTree);
		print "\t\tclean($dupRemove): $workTree\n" if ($debug and not $dupRemove);
		}
	print "\tFinished!!!\n" if ($debug);
	
	$workTree = cladeClean($workTree);	# Remove any empty clades
	return ($workTree);
	}

sub cleanTree	# Subroutine to remove extraneous markers from tree description due to pruning taxa
	{
	my $dirtyTree = shift;
	undef @delPositions;

	my $changeCount = 1;
	until ($changeCount == 0)	# Remove most empty clade markers from pruned ST description
		{
		$changeCount = $dirtyTree =~ s/,,/,/g;
		$changeCount += $dirtyTree =~ s/\(\)//g;
		$changeCount += $dirtyTree =~ s/\(,\)//g;
		$changeCount += $dirtyTree =~ s/\(,\(/\(\(/g;
		$changeCount += $dirtyTree =~ s/\),\)/\)\)/g;
		$changeCount += $dirtyTree =~ s/,\)/\)/g;
		$changeCount += $dirtyTree =~ s/\(,/\(/g;
		foreach my $species (@treeSpecies)
			{
			$changeCount += $dirtyTree =~ s/\($species\)/$species/g;
			}
		}
#	$totalClade = ($dirtyTree =~ tr/(//);	# Remove remaining empty clades from pruned ST
	# Fix for trees synonymized to a single taxon; cleanTree will eventually strip all parentheses, causing endless loop at line 339
		if (substr($dirtyTree, 0, 1) ne "(" and substr($dirtyTree, length($dirtyTree), 1) ne ")")
			{
			$dirtyTree = "(".$dirtyTree.")";
			}
	return $dirtyTree;
	}

sub paraPermutation		# Subroutine to output all unique permutations of a source tree with paraphyletic species represented once only
	{
	my $treeName = shift;
	my $permTree = shift;
	
	my $permTotal = 1;
	my (%cutOff, %inclCount, %permPresent, %permRejected, @acceptList);
	foreach my $species (@paraList)
		{
		$permTotal *= $presentTree{$species};
		}
	print "\n\tPermuting paraphyletic species ...\n\t\tNo. of permutations: $permTotal\n" if ($debug);
	my $permTemp = $permTotal;
	foreach my $species (@paraList)
		{
		$cutOff{$species} = $permTemp / $presentTree{$species};
		$inclCount{$species} = 1;
		$permTemp /= $presentTree{$species};
		print "\t\t\tSpecies: $species\tcutOff: $cutOff{$species}\n" if ($debug);
		}
	for (my $i = 1; $i <= $permTotal; $i++)
		{
		print "\n\t\tIteration: $i\n" if ($debug);
		print "\t$permTree\n" if ($debug);
		
		my $prunedTree;
		foreach my $species (@paraList)
			{
			my $value = ($i-1) / $cutOff{$species};
			if (int($value) == $value and $value)
				{
				$inclCount{$species}++;
				}
			if ($inclCount{$species} > $presentTree{$species})
				{
				$inclCount{$species} = 1;
				}
			}

		my $position = 0;
		my $offset;
		my %paraCount;
		my $cladeCount = 0;
		while ($position < length($permTree))
			{
			$offset = 1;
			if (substr($permTree, $position, 1) eq "(")		# New clade; go one level deeper
				{
				$prunedTree .= "(";
				$cladeCount++;
				print "\t\t\tClade $cladeCount:\n" if ($debug);
				}
			elsif (substr($permTree, $position, 1) eq ")")	# Clade finished; clean up and go up one level
				{
				$prunedTree .= ")";
				}
			elsif (substr($permTree, $position, 1) eq ",")
				{
				$prunedTree .= ",";
				}
			else	# Determine taxa in clade
				{
				until (substr($permTree, $position+$offset, 1) eq "(" or substr($permTree, $position+$offset, 1) eq ")" or substr($permTree, $position+$offset, 1) eq ",")
					{
					$offset++;
					}
				my $taxon = substr($permTree, $position, $offset);
				print "\t\t\t\t$taxon\n" if ($debug);
				if ($para{$taxon})
					{
					$paraCount{$taxon}++;
					print "\t\t\t\t\t$paraCount{$taxon} occurence of $taxon" if ($debug);
					if ($paraCount{$taxon} == $inclCount{$taxon})
						{
						$prunedTree .= "$taxon";
						print ": included" if ($debug);
						}
					print "\n" if ($debug);
					}
				else
					{
					$prunedTree .= "$taxon";
					}
				$position += $offset-1;
				}
			$position++;
			}
		$prunedTree = cleanTree($prunedTree);
		print "\n\t\t\tparaTree: $prunedTree\n" if ($debug);
		$prunedTree = cladeClean($prunedTree);
		print "\t\t\tCleaned paraTree: $prunedTree\n" if ($debug);
		
		# Check whether permuted tree description is unique
			# Check first whether it exactly matches an accepted or rejected tree; faster than calculating partition metric
				if (not $permPresent{$prunedTree} and not $permRejected{$prunedTree})	# No exact match; calculate dS
					{
					if (not scalar(@acceptList))	# First tree to be examined; store
						{
						push @acceptList, $prunedTree;
						$permPresent{$prunedTree} = 1;
						my $num = keys %permPresent;
						print WRITE "\t\ttree $treeName"."_$num = $prunedTree;\n";
						print "\n\t\t\tFirst tree examined: accepted\n" if ($debug);
						}
					else
						{
						my @testList;
							push @testList, $prunedTree, @acceptList;
							
						my $dS = partitionMetric(@testList);	# Get minimum dS between pruned tree and acceptList
						
						if ($dS > 0)	# Pruned tree is different from all trees on acceptList
							{
							push @acceptList, $prunedTree;
							$permPresent{$prunedTree} = 1;
							my $num = keys %permPresent;
							print WRITE "\t\ttree $treeName"."_$num = $prunedTree;\n";
							print "\n\t\t\tUnique permutation (min dS = $dS): accepted\n" if ($debug);
							}
						else
							{
							$permRejected{$prunedTree} = 1;
							print "\n\t\t\tIdentical with previous permutation by dS (min dS = $dS): rejected\n" if ($debug);
							}
						}
					}
				else
					{
					print "\t\tIdentical with previous permutation by string match: rejected\n" if ($debug);
					}
		}
	}
	
sub cladeClean	# Subroutine to remove "empty" clades from tree description
	{
	my $workTree = shift;
	my ($position, $CladeID, $CurrentClade) = (0, 0, 0);
	my (@ParentClade, @CladeDescrip, $OldCurrent, %present, @start, @stop);
	my $offset;
	
	while ($position < length($workTree))	# Get clade descriptions
		{
		$offset = 1;
		if (substr($workTree, $position, 1) eq "(")		# New clade; go one level deeper
			{
			$CladeID++;
			$ParentClade[$CladeID] = $CurrentClade;
			$CurrentClade = $CladeID;
			$start[$CladeID] = $position;
			}
		elsif (substr($workTree, $position, 1) eq ")")	# Clade finished; clean up and go up one level
			{
			$OldCurrent = $CurrentClade;
			$CurrentClade = $ParentClade[$OldCurrent];
			$stop[$OldCurrent] = $position;
			$CladeDescrip[$OldCurrent] = substr($workTree, $start[$OldCurrent], $stop[$OldCurrent]-$start[$OldCurrent]+1);
			}
		elsif (substr($workTree, $position, 1) eq ",")
			{
			}
		else	#Determine membership of clade
			{
			until (substr($workTree, $position+$offset, 1) eq "(" or substr($workTree, $position+$offset, 1) eq ")" or substr($workTree, $position+$offset, 1) eq ",")
				{
				$offset++;
				}
			$position += $offset-1;
			}
		$position++;
		}

	my $totalClade = ($workTree =~ tr/(//);	# Compare clade descriptions to remove remaining empty clades from pruned ST
	for (my $clade = 1; $clade <= $totalClade; $clade++)
		{
		print "description of $clade: $CladeDescrip[$clade]\n" if ($debug);
		my $workClade = $CladeDescrip[$clade];		# Get species names in clade
			$workClade =~ s/\(//g;
			$workClade =~ s/\)//g;
		print "\twork: $workClade\n" if ($debug);
		if (not $present{$workClade})
			{
			$present{$workClade} = 1;
			}
		else	# Clade duplicates one already described; get positions of parentheses for deletion
			{
			print "start: $start[$clade]\tstop: $stop[$clade]\n" if ($debug);
			push @delPositions, $start[$clade];
			push @delPositions, $stop[$clade];
			}
		}
	my @sortDel = sort {$b <=> $a} @delPositions;
	foreach my $position (@sortDel)
		{
		print "del: $position\n"  if ($debug);
		substr($workTree, $position, 1, "");
		}
	$workTree =~ s/\s//g;
	print "\t\tEmpty clean: $workTree\n" if ($debug);
	return $workTree;
	}

sub partitionMetric
	{
	my @treeList = @_;
	my $finalTree = scalar(@treeList - 2);
		$finalTree = 0 if ($compType eq "ref");
	my $min_dS;
	
	for (my $treeCount1 = 0; $treeCount1 <= $finalTree; $treeCount1++)
		{
		my $tree1 = $treeList[$treeCount1];
		print "Comparing versus tree $treeCount1\n\t$tree1\n" if ($verbose);
		my @refPlots;
			push @refPlots, dotPlotter($tree1);
		
		for (my $treeCount2 = $treeCount1 + 1; $treeCount2 < scalar(@treeList); $treeCount2++)
			{
			my $tree2 = $treeList[$treeCount2];
			print "\tComparing versus tree $treeCount2\n\t\t$tree2\n" if ($verbose);
			my @dotPlots = @refPlots;
				push @dotPlots, dotPlotter($tree2);

			my (%plotCount, @plotList);
			my $dS = 0;
			
			foreach my $plot (@dotPlots)
				{
				$plotCount{$plot}++;
				if ($plotCount{$plot} == 1)
					{
					$dS++; 
					push @plotList, $plot;
					}
				$dS-- if ($plotCount{$plot} == 2);
				print "$plot ($plotCount{$plot}; dS = $dS)\n" if ($verbose);
				}
			print "Tree $treeCount1 vs. tree $treeCount2: dS = $dS\n" if ($verbose);
#			$dSlist{$tree1}{$tree2} = $dS;
			$min_dS = $dS if (not defined $min_dS or $dS < $min_dS);
			last if ($min_dS == 0);	# Have identity; no need to check further
			}
		}
	return $min_dS;
	}

sub dotPlotter
	{
	my $tree = shift;
		print "Tree description:\n\t$tree\n" if ($verbose);
	
	my (%ParentClade, %CladeDescrip, %CladeSupport, %open, %start, %stop, %present);
	my (@taxonList, @dotPlots, %plotCount);
	
	my $totalClade = ($tree =~ tr/(//);
	my ($position, $CladeID, $CurrentClade) = (0, 0, 0);
	my $OldCurrent;
	
	while ($position < length($tree))
		{
		my $offset = 1;
		if (substr($tree, $position, 1) eq "(")		# New clade; go one level deeper
			{
			$CladeID++;
			$ParentClade{$CladeID} = $CurrentClade;
			$CurrentClade = $CladeID;
			$open{$CurrentClade} = 1;
			$start{$CladeID} = $position;
			}
		elsif (substr($tree, $position, 1) eq ")")	# Clade finished; clean up and go up one level
			{
			$open{$CurrentClade} = 0;
			$OldCurrent = $CurrentClade;
			$CurrentClade = $ParentClade{$OldCurrent};
			$stop{$OldCurrent} = $position;
			$CladeDescrip{$OldCurrent} = substr($tree, $start{$OldCurrent}, $stop{$OldCurrent}-$start{$OldCurrent}+1);
			$CladeDescrip{$OldCurrent} =~ s/:\d+\.?\d*//g;	# Remove branch length information
			}
		elsif (substr($tree, $position, 1) eq ":")	# Branch lengths present; record as nodal support
			{
			until (substr($tree, $position+$offset, 1) eq "(" or substr($tree, $position+$offset, 1) eq ")" or substr($tree, $position+$offset, 1) eq "," or $position+$offset >= length($tree))
				{
				$offset++;
				}
			$position += $offset-1;
			}
		elsif (substr($tree, $position, 1) eq ",")
			{
			# Do nothing
			}
		elsif (substr($tree, $position, 1) eq "[")	# Skip over embedded comment
			{
			until (substr($tree, $position+$offset, 1) eq "]" or $position+$offset >= length($tree))
				{
				$offset++;
				}
			$position += $offset-1;
			}
		else	# Determine membership of clade
			{
			my $prevChar = substr($tree, $position-1, 1);
			until (substr($tree, $position+$offset, 1) eq "(" or substr($tree, $position+$offset, 1) eq ")" or substr($tree, $position+$offset, 1) eq "," or substr($tree, $position+$offset, 1) eq ":" or $position+$offset >= length($tree))
				{
				$offset++;
				}
			unless ($prevChar eq ")")	# Text represents a node label and not a taxon
				{
				push @taxonList, substr($tree, $position, $offset);
				for (my $clade = 1; $clade <= $CladeID; $clade++)	# Assign taxon to any open clades
					{
					if ($open{$clade})
						{
						$present{substr($tree, $position, $offset)}{$clade} = 1;
						}
					}
				}
			$position += $offset-1;
			}
		$position++;
		}

	# Create dot plots
		@taxonList = sort(@taxonList);
		for (my $clade = 1; $clade <= $totalClade; $clade++)
			{
			print "Clade $clade:\n\t$CladeDescrip{$clade}\n" if ($verbose);
			my $dotPlot;
			foreach my $taxon (@taxonList)
				{
				if ($present{$taxon}{$clade})
					{
					$dotPlot .= "*";
					}
				else
					{
					$dotPlot .= ".";
					}
				}

			# Only store informative clades
				next unless ($dotPlot =~ /\./ and $dotPlot =~ /\*/);
				next unless (scalar(@taxonList - ($dotPlot =~ tr/\*//)) > 1);

			$dotPlot = invertPlot($dotPlot) if ($dotPlot =~ /^\*/);	# Invert plot to common frame of reference to account for unrooted trees
			$plotCount{$dotPlot}++;
				print "\tDot plot: $dotPlot\n" if ($verbose);
				if ($plotCount{$dotPlot} == 1)	# Only store unique plots
					{
					push @dotPlots, $dotPlot;
					}
				else
					{
					print "\t\tNot unique ...\n" if ($verbose);
					}
			}
			
	return @dotPlots;
	}

sub invertPlot
	{
	my $plot = shift;
	my $invertedPlot;
	
	for (my $i = 0; $i < length($plot); $i++)
		{
		if (substr($plot, $i, 1) eq ".")
			{
			$invertedPlot .= "*";
			}
		else
			{
			$invertedPlot .= ".";
			}
		}
		
	return $invertedPlot;
	}

sub setLineBreak	# Check line breaks of input files and set input record separator accordingly
	{
	my $inFile = shift;
	$/ ="\n";
	open (IN, "<$inFile") or die "Cannot open $inFile to check form of line breaks.\n";
		while (<IN>)
			{
			if ($_ =~ /\r\n/)
				{
				print "DOS line breaks detected ...\n" if ($verbose);
				$/ ="\r\n";
				last;
				}
			elsif ($_ =~ /\r/)
				{
				print "Mac line breaks detected ...\n" if ($verbose);
				$/ ="\r";
				last;
				}
			else
				{
				print "Unix line breaks detected ...\n" if ($verbose);
				$/ ="\n";
				last;
				}
			}
	close IN;
	}

sub WRread		# Subroutine to input Wilson and Reeder (1993), or desired parts thereof, to a hash
	{
	my @searchOrder = @_;
	my %orderList = (Monotremata => 1,
		Xenarthra => 1,
		Proboscidea => 1,
		Insectivora => 1,
		Scandentia => 1,
		Sirenia => 1,
		Chiroptera => 1,
		Primates => 1,
		Carnivora => 1,
		Cetacea => 1,
		Hyracoidea => 1,
		Rodentia => 1,
		Lagomorpha => 1,
		Didelphimorphia => 1,
		Dermoptera => 1,
		Perissodactyla => 1,
		Tubulidentata => 1,
		Paucituberculata => 1,
		Artiodactyla => 1,
		Pholidota => 1,
		Microbiotheria => 1,
		Macroscelidea => 1,
		Dasyuromorphia => 1,
		Peramelemorphia => 1,
		Notoryctemorphia => 1,
		Diprotodontia => 1);
	my %speciesList;
	
	# Associate WR(1993) species to order
		@{ $speciesList{Monotremata} } = qw(Tachyglossus_aculeatus
			Zaglossus_bruijni
			Ornithorhynchus_anatinus);
		@{ $speciesList{Didelphimorphia} } = qw(Caluromys_derbianus
			Caluromys_lanatus
			Caluromys_philander
			Caluromysiops_irrupta
			Glironia_venusta
			Chironectes_minimus
			Didelphis_albiventris
			Didelphis_aurita
			Didelphis_marsupialis
			Didelphis_virginiana
			Gracilinanus_aceramarcae
			Gracilinanus_agilis
			Gracilinanus_dryas
			Gracilinanus_emiliae
			Gracilinanus_marica
			Gracilinanus_microtarsus
			Lestodelphys_halli
			Lutreolina_crassicaudata
			Marmosa_andersoni
			Marmosa_canescens
			Marmosa_lepida
			Marmosa_mexicana
			Marmosa_murina
			Marmosa_robinsoni
			Marmosa_rubra
			Marmosa_tyleriana
			Marmosa_xerophila
			Marmosops_cracens
			Marmosops_dorothea
			Marmosops_fuscatus
			Marmosops_handleyi
			Marmosops_impavidus
			Marmosops_incanus
			Marmosops_invictus
			Marmosops_noctivagus
			Marmosops_parvidens
			Metachirus_nudicaudatus
			Micoureus_alstoni
			Micoureus_constantiae
			Micoureus_demerarae
			Micoureus_regina
			Monodelphis_adusta
			Monodelphis_americana
			Monodelphis_brevicaudata
			Monodelphis_dimidiata
			Monodelphis_domestica
			Monodelphis_emiliae
			Monodelphis_iheringi
			Monodelphis_kunsi
			Monodelphis_maraxina
			Monodelphis_osgoodi
			Monodelphis_rubida
			Monodelphis_scalops
			Monodelphis_sorex
			Monodelphis_theresa
			Monodelphis_unistriata
			Philander_andersoni
			Philander_opossum
			Thylamys_elegans
			Thylamys_macrura
			Thylamys_pallidior
			Thylamys_pusilla
			Thylamys_velutinus);
		@{ $speciesList{Paucituberculata} } = qw(Caenolestes_caniventer
			Caenolestes_convelatus
			Caenolestes_fuliginosus
			Lestoros_inca
			Rhyncholestes_raphanurus);
		@{ $speciesList{Microbiotheria} } = qw(Dromiciops_gliroides);
		@{ $speciesList{Dasyuromorphia} } = qw(Thylacinus_cynocephalus
			Myrmecobius_fasciatus
			Antechinus_bellus
			Antechinus_flavipes
			Antechinus_godmani
			Antechinus_leo
			Antechinus_melanurus
			Antechinus_minimus
			Antechinus_naso
			Antechinus_stuartii
			Antechinus_swainsonii
			Antechinus_wilhelmina
			Dasycercus_byrnei
			Dasycercus_cristicauda
			Dasykaluta_rosamondae
			Dasyurus_albopunctatus
			Dasyurus_geoffroii
			Dasyurus_hallucatus
			Dasyurus_maculatus
			Dasyurus_spartacus
			Dasyurus_viverrinus
			Murexia_longicaudata
			Murexia_rothschildi
			Myoictis_melas
			Neophascogale_lorentzi
			Ningaui_ridei
			Ningaui_timealeyi
			Ningaui_yvonnae
			Parantechinus_apicalis
			Parantechinus_bilarni
			Phascogale_calura
			Phascogale_tapoatafa
			Phascolosorex_doriae
			Phascolosorex_dorsalis
			Planigale_gilesi
			Planigale_ingrami
			Planigale_maculata
			Planigale_novaeguineae
			Planigale_tenuirostris
			Pseudantechinus_macdonnellensis
			Pseudantechinus_ningbing
			Pseudantechinus_woolleyae
			Sarcophilus_laniarius
			Sminthopsis_aitkeni
			Sminthopsis_archeri
			Sminthopsis_butleri
			Sminthopsis_crassicaudata
			Sminthopsis_dolichura
			Sminthopsis_douglasi
			Sminthopsis_fuliginosus
			Sminthopsis_gilberti
			Sminthopsis_granulipes
			Sminthopsis_griseoventer
			Sminthopsis_hirtipes
			Sminthopsis_laniger
			Sminthopsis_leucopus
			Sminthopsis_longicaudata
			Sminthopsis_macroura
			Sminthopsis_murina
			Sminthopsis_ooldea
			Sminthopsis_psammophila
			Sminthopsis_virginiae
			Sminthopsis_youngsoni);
		@{ $speciesList{Peramelemorphia} } = qw(Chaeropus_ecaudatus
			Isoodon_auratus
			Isoodon_macrourus
			Isoodon_obesulus
			Macrotis_lagotis
			Macrotis_leucura
			Perameles_bougainville
			Perameles_eremiana
			Perameles_gunnii
			Perameles_nasuta
			Echymipera_clara
			Echymipera_davidi
			Echymipera_echinista
			Echymipera_kalubu
			Echymipera_rufescens
			Microperoryctes_longicauda
			Microperoryctes_murina
			Microperoryctes_papuensis
			Peroryctes_broadbenti
			Peroryctes_raffrayana
			Rhynchomeles_prattorum);
		@{ $speciesList{Notoryctemorphia} } = qw(Notoryctes_caurinus
			Notoryctes_typhlops);
		@{ $speciesList{Diprotodontia} } = qw(Phascolarctos_cinereus
			Lasiorhinus_krefftii
			Lasiorhinus_latifrons
			Vombatus_ursinus
			Ailurops_ursinus
			Phalanger_carmelitae
			Phalanger_lullulae
			Phalanger_matanim
			Phalanger_orientalis
			Phalanger_ornatus
			Phalanger_pelengensis
			Phalanger_rothschildi
			Phalanger_sericeus
			Phalanger_vestitus
			Spilocuscus_maculatus
			Spilocuscus_rufoniger
			Strigocuscus_celebensis
			Strigocuscus_gymnotis
			Trichosurus_arnhemensis
			Trichosurus_caninus
			Trichosurus_vulpecula
			Wyulda_squamicaudata
			Aepyprymnus_rufescens
			Bettongia_gaimardi
			Bettongia_lesueur
			Bettongia_penicillata
			Caloprymnus_campestris
			Hypsiprymnodon_moschatus
			Potorous_longipes
			Potorous_platyops
			Potorous_tridactylus
			Dendrolagus_bennettianus
			Dendrolagus_dorianus
			Dendrolagus_goodfellowi
			Dendrolagus_inustus
			Dendrolagus_lumholtzi
			Dendrolagus_matschiei
			Dendrolagus_scottae
			Dendrolagus_spadix
			Dendrolagus_ursinus
			Dorcopsis_atrata
			Dorcopsis_hageni
			Dorcopsis_luctuosa
			Dorcopsis_muelleri
			Dorcopsulus_macleayi
			Dorcopsulus_vanheurni
			Lagorchestes_asomatus
			Lagorchestes_conspicillatus
			Lagorchestes_hirsutus
			Lagorchestes_leporides
			Lagostrophus_fasciatus
			Macropus_agilis
			Macropus_antilopinus
			Macropus_bernardus
			Macropus_dorsalis
			Macropus_eugenii
			Macropus_fuliginosus
			Macropus_giganteus
			Macropus_greyi
			Macropus_irma
			Macropus_parma
			Macropus_parryi
			Macropus_robustus
			Macropus_rufogriseus
			Macropus_rufus
			Onychogalea_fraenata
			Onychogalea_lunata
			Onychogalea_unguifera
			Petrogale_assimilis
			Petrogale_brachyotis
			Petrogale_burbidgei
			Petrogale_concinna
			Petrogale_godmani
			Petrogale_inornata
			Petrogale_lateralis
			Petrogale_penicillata
			Petrogale_persephone
			Petrogale_rothschildi
			Petrogale_xanthopus
			Setonix_brachyurus
			Thylogale_billardierii
			Thylogale_brunii
			Thylogale_stigmatica
			Thylogale_thetis
			Wallabia_bicolor
			Burramys_parvus
			Cercartetus_caudatus
			Cercartetus_concinnus
			Cercartetus_lepidus
			Cercartetus_nanus
			Hemibelideus_lemuroides
			Petauroides_volans
			Petropseudes_dahli
			Pseudocheirus_canescens
			Pseudocheirus_caroli
			Pseudocheirus_forbesi
			Pseudocheirus_herbertensis
			Pseudocheirus_mayeri
			Pseudocheirus_peregrinus
			Pseudocheirus_schlegeli
			Pseudochirops_albertisii
			Pseudochirops_archeri
			Pseudochirops_corinnae
			Pseudochirops_cupreus
			Dactylopsila_megalura
			Dactylopsila_palpator
			Dactylopsila_tatei
			Dactylopsila_trivirgata
			Gymnobelideus_leadbeateri
			Petaurus_abidi
			Petaurus_australis
			Petaurus_breviceps
			Petaurus_gracilis
			Petaurus_norfolcensis
			Tarsipes_rostratus
			Acrobates_pygmaeus
			Distoechurus_pennatus);
		@{ $speciesList{Xenarthra} } = qw(Bradypus_torquatus
			Bradypus_tridactylus
			Bradypus_variegatus
			Choloepus_didactylus
			Choloepus_hoffmanni
			Chlamyphorus_retusus
			Chlamyphorus_truncatus
			Cabassous_centralis
			Cabassous_chacoensis
			Cabassous_tatouay
			Cabassous_unicinctus
			Chaetophractus_nationi
			Chaetophractus_vellerosus
			Chaetophractus_villosus
			Dasypus_hybridus
			Dasypus_kappleri
			Dasypus_novemcinctus
			Dasypus_pilosus
			Dasypus_sabanicola
			Dasypus_septemcinctus
			Euphractus_sexcinctus
			Priodontes_maximus
			Tolypeutes_matacus
			Tolypeutes_tricinctus
			Zaedyus_pichiy
			Cyclopes_didactylus
			Myrmecophaga_tridactyla
			Tamandua_mexicana
			Tamandua_tetradactyla);
		@{ $speciesList{Insectivora} } = qw(Solenodon_cubanus
			Solenodon_marcanoi
			Solenodon_paradoxus
			Nesophontes_edithae
			Nesophontes_hypomicrus
			Nesophontes_longirostris
			Nesophontes_major
			Nesophontes_micrus
			Nesophontes_paramicrus
			Nesophontes_submicrus
			Nesophontes_zamicrus
			Geogale_aurita
			Limnogale_mergulus
			Microgale_brevicaudata
			Microgale_cowani
			Microgale_dobsoni
			Microgale_dryas
			Microgale_gracilis
			Microgale_longicaudata
			Microgale_parvula
			Microgale_principula
			Microgale_pulla
			Microgale_pusilla
			Microgale_talazaci
			Microgale_thomasi
			Oryzorictes_hova
			Oryzorictes_talpoides
			Oryzorictes_tetradactylus
			Micropotamogale_lamottei
			Micropotamogale_ruwenzorii
			Potamogale_velox
			Echinops_telfairi
			Hemicentetes_semispinosus
			Setifer_setosus
			Tenrec_ecaudatus
			Amblysomus_gunningi
			Amblysomus_hottentotus
			Amblysomus_iris
			Amblysomus_julianae
			Calcochloris_obtusirostris
			Chlorotalpa_arendsi
			Chlorotalpa_duthieae
			Chlorotalpa_leucorhina
			Chlorotalpa_sclateri
			Chlorotalpa_tytonis
			Chrysochloris_asiatica
			Chrysochloris_stuhlmanni
			Chrysochloris_visagiei
			Chrysospalax_trevelyani
			Chrysospalax_villosus
			Cryptochloris_wintoni
			Cryptochloris_zyli
			Eremitalpa_granti
			Atelerix_albiventris
			Atelerix_algirus
			Atelerix_frontalis
			Atelerix_sclateri
			Erinaceus_amurensis
			Erinaceus_concolor
			Erinaceus_europaeus
			Hemiechinus_aethiopicus
			Hemiechinus_auritus
			Hemiechinus_collaris
			Hemiechinus_hypomelas
			Hemiechinus_micropus
			Hemiechinus_nudiventris
			Mesechinus_dauuricus
			Mesechinus_hughi
			Echinosorex_gymnura
			Hylomys_hainanensis
			Hylomys_sinensis
			Hylomys_suillus
			Podogymnura_aureospinula
			Podogymnura_truei
			Congosorex_polli
			Crocidura_aleksandrisi
			Crocidura_allex
			Crocidura_andamanensis
			Crocidura_ansellorum
			Crocidura_arabica
			Crocidura_armenica
			Crocidura_attenuata
			Crocidura_attila
			Crocidura_baileyi
			Crocidura_batesi
			Crocidura_beatus
			Crocidura_beccarii
			Crocidura_bottegi
			Crocidura_bottegoides
			Crocidura_buettikoferi
			Crocidura_caliginea
			Crocidura_canariensis
			Crocidura_cinderella
			Crocidura_congobelgica
			Crocidura_cossyrensis
			Crocidura_crenata
			Crocidura_crossei
			Crocidura_cyanea
			Crocidura_denti
			Crocidura_desperata
			Crocidura_dhofarensis
			Crocidura_dolichura
			Crocidura_douceti
			Crocidura_dsinezumi
			Crocidura_eisentrauti
			Crocidura_elgonius
			Crocidura_elongata
			Crocidura_erica
			Crocidura_fischeri
			Crocidura_flavescens
			Crocidura_floweri
			Crocidura_foxi
			Crocidura_fuliginosa
			Crocidura_fulvastra
			Crocidura_fumosa
			Crocidura_fuscomurina
			Crocidura_glassi
			Crocidura_goliath
			Crocidura_gracilipes
			Crocidura_grandiceps
			Crocidura_grandis
			Crocidura_grassei
			Crocidura_grayi
			Crocidura_greenwoodi
			Crocidura_gueldenstaedtii
			Crocidura_harenna
			Crocidura_hildegardeae
			Crocidura_hirta
			Crocidura_hispida
			Crocidura_horsfieldii
			Crocidura_jacksoni
			Crocidura_jenkinsi
			Crocidura_kivuana
			Crocidura_lamottei
			Crocidura_lanosa
			Crocidura_lasiura
			Crocidura_latona
			Crocidura_lea
			Crocidura_leucodon
			Crocidura_levicula
			Crocidura_littoralis
			Crocidura_longipes
			Crocidura_lucina
			Crocidura_ludia
			Crocidura_luna
			Crocidura_lusitania
			Crocidura_macarthuri
			Crocidura_macmillani
			Crocidura_macowi
			Crocidura_malayana
			Crocidura_manengubae
			Crocidura_maquassiensis
			Crocidura_mariquensis
			Crocidura_maurisca
			Crocidura_maxi
			Crocidura_mindorus
			Crocidura_minuta
			Crocidura_miya
			Crocidura_monax
			Crocidura_monticola
			Crocidura_montis
			Crocidura_muricauda
			Crocidura_mutesae
			Crocidura_nana
			Crocidura_nanilla
			Crocidura_neglecta
			Crocidura_negrina
			Crocidura_nicobarica
			Crocidura_nigeriae
			Crocidura_nigricans
			Crocidura_nigripes
			Crocidura_nigrofusca
			Crocidura_nimbae
			Crocidura_niobe
			Crocidura_obscurior
			Crocidura_olivieri
			Crocidura_orii
			Crocidura_osorio
			Crocidura_palawanensis
			Crocidura_paradoxura
			Crocidura_parvipes
			Crocidura_pasha
			Crocidura_pergrisea
			Crocidura_phaeura
			Crocidura_picea
			Crocidura_pitmani
			Crocidura_planiceps
			Crocidura_poensis
			Crocidura_polia
			Crocidura_pullata
			Crocidura_raineyi
			Crocidura_religiosa
			Crocidura_rhoditis
			Crocidura_roosevelti
			Crocidura_russula
			Crocidura_selina
			Crocidura_serezkyensis
			Crocidura_sibirica
			Crocidura_sicula
			Crocidura_silacea
			Crocidura_smithii
			Crocidura_somalica
			Crocidura_stenocephala
			Crocidura_suaveolens
			Crocidura_susiana
			Crocidura_tansaniana
			Crocidura_tarella
			Crocidura_tarfayensis
			Crocidura_telfordi
			Crocidura_tenuis
			Crocidura_thalia
			Crocidura_theresae
			Crocidura_thomensis
			Crocidura_turba
			Crocidura_ultima
			Crocidura_usambarae
			Crocidura_viaria
			Crocidura_voi
			Crocidura_whitakeri
			Crocidura_wimmeri
			Crocidura_xantippe
			Crocidura_yankariensis
			Crocidura_zaphiri
			Crocidura_zarudnyi
			Crocidura_zimmeri
			Crocidura_zimmermanni
			Diplomesodon_pulchellum
			Feroculus_feroculus
			Myosorex_babaulti
			Myosorex_blarina
			Myosorex_cafer
			Myosorex_eisentrauti
			Myosorex_geata
			Myosorex_longicaudatus
			Myosorex_okuensis
			Myosorex_rumpii
			Myosorex_schalleri
			Myosorex_sclateri
			Myosorex_tenuis
			Myosorex_varius
			Paracrocidura_graueri
			Paracrocidura_maxima
			Paracrocidura_schoutedeni
			Ruwenzorisorex_suncoides
			Scutisorex_somereni
			Solisorex_pearsoni
			Suncus_ater
			Suncus_dayi
			Suncus_etruscus
			Suncus_fellowesgordoni
			Suncus_hosei
			Suncus_infinitesimus
			Suncus_lixus
			Suncus_madagascariensis
			Suncus_malayanus
			Suncus_mertensi
			Suncus_montanus
			Suncus_murinus
			Suncus_remyi
			Suncus_stoliczkanus
			Suncus_varilla
			Suncus_zeylanicus
			Surdisorex_norae
			Surdisorex_polulus
			Sylvisorex_granti
			Sylvisorex_howelli
			Sylvisorex_isabellae
			Sylvisorex_johnstoni
			Sylvisorex_lunaris
			Sylvisorex_megalura
			Sylvisorex_morio
			Sylvisorex_ollula
			Sylvisorex_oriundus
			Sylvisorex_vulcanorum
			Anourosorex_squamipes
			Blarina_brevicauda
			Blarina_carolinensis
			Blarina_hylophaga
			Blarinella_quadraticauda
			Blarinella_wardi
			Chimarrogale_hantu
			Chimarrogale_himalayica
			Chimarrogale_phaeura
			Chimarrogale_platycephala
			Chimarrogale_styani
			Chimarrogale_sumatrana
			Cryptotis_avia
			Cryptotis_endersi
			Cryptotis_goldmani
			Cryptotis_goodwini
			Cryptotis_gracilis
			Cryptotis_hondurensis
			Cryptotis_magna
			Cryptotis_meridensis
			Cryptotis_mexicana
			Cryptotis_montivaga
			Cryptotis_nigrescens
			Cryptotis_parva
			Cryptotis_squamipes
			Cryptotis_thomasi
			Megasorex_gigas
			Nectogale_elegans
			Neomys_anomalus
			Neomys_fodiens
			Neomys_schelkovnikovi
			Notiosorex_crawfordi
			Sorex_alaskanus
			Sorex_alpinus
			Sorex_araneus
			Sorex_arcticus
			Sorex_arizonae
			Sorex_asper
			Sorex_bairdii
			Sorex_bedfordiae
			Sorex_bendirii
			Sorex_buchariensis
			Sorex_caecutiens
			Sorex_camtschatica
			Sorex_cansulus
			Sorex_cinereus
			Sorex_coronatus
			Sorex_cylindricauda
			Sorex_daphaenodon
			Sorex_dispar
			Sorex_emarginatus
			Sorex_excelsus
			Sorex_fumeus
			Sorex_gaspensis
			Sorex_gracillimus
			Sorex_granarius
			Sorex_haydeni
			Sorex_hosonoi
			Sorex_hoyi
			Sorex_hydrodromus
			Sorex_isodon
			Sorex_jacksoni
			Sorex_kozlovi
			Sorex_leucogaster
			Sorex_longirostris
			Sorex_lyelli
			Sorex_macrodon
			Sorex_merriami
			Sorex_milleri
			Sorex_minutissimus
			Sorex_minutus
			Sorex_mirabilis
			Sorex_monticolus
			Sorex_nanus
			Sorex_oreopolus
			Sorex_ornatus
			Sorex_pacificus
			Sorex_palustris
			Sorex_planiceps
			Sorex_portenkoi
			Sorex_preblei
			Sorex_raddei
			Sorex_roboratus
			Sorex_sadonis
			Sorex_samniticus
			Sorex_satunini
			Sorex_saussurei
			Sorex_sclateri
			Sorex_shinto
			Sorex_sinalis
			Sorex_sonomae
			Sorex_stizodon
			Sorex_tenellus
			Sorex_thibetanus
			Sorex_trowbridgii
			Sorex_tundrensis
			Sorex_ugyunak
			Sorex_unguiculatus
			Sorex_vagrans
			Sorex_ventralis
			Sorex_veraepacis
			Sorex_volnuchini
			Soriculus_caudatus
			Soriculus_fumidus
			Soriculus_hypsibius
			Soriculus_lamula
			Soriculus_leucops
			Soriculus_macrurus
			Soriculus_nigrescens
			Soriculus_parca
			Soriculus_salenskii
			Soriculus_smithii
			Desmana_moschata
			Galemys_pyrenaicus
			Condylura_cristata
			Euroscaptor_grandis
			Euroscaptor_klossi
			Euroscaptor_longirostris
			Euroscaptor_micrura
			Euroscaptor_mizura
			Euroscaptor_parvidens
			Mogera_etigo
			Mogera_insularis
			Mogera_kobeae
			Mogera_minor
			Mogera_robusta
			Mogera_tokudae
			Mogera_wogura
			Nesoscaptor_uchidai
			Neurotrichus_gibbsii
			Parascalops_breweri
			Parascaptor_leucura
			Scalopus_aquaticus
			Scapanulus_oweni
			Scapanus_latimanus
			Scapanus_orarius
			Scapanus_townsendii
			Scaptochirus_moschatus
			Scaptonyx_fusicaudus
			Talpa_altaica
			Talpa_caeca
			Talpa_caucasica
			Talpa_europaea
			Talpa_levantis
			Talpa_occidentalis
			Talpa_romana
			Talpa_stankovici
			Talpa_streeti
			Urotrichus_pilirostris
			Urotrichus_talpoides
			Uropsilus_andersoni
			Uropsilus_gracilis
			Uropsilus_investigator
			Uropsilus_soricipes);
		@{ $speciesList{Scandentia} } = qw(Anathana_ellioti
			Dendrogale_melanura
			Dendrogale_murina
			Tupaia_belangeri
			Tupaia_chrysogaster
			Tupaia_dorsalis
			Tupaia_glis
			Tupaia_gracilis
			Tupaia_javanica
			Tupaia_longipes
			Tupaia_minor
			Tupaia_montana
			Tupaia_nicobarica
			Tupaia_palawanensis
			Tupaia_picta
			Tupaia_splendidula
			Tupaia_tana
			Urogale_everetti
			Ptilocercus_lowii);
		@{ $speciesList{Dermoptera} } = qw(Cynocephalus_variegatus
			Cynocephalus_volans);
		@{ $speciesList{Chiroptera} } = qw(Acerodon_celebensis
			Acerodon_humilis
			Acerodon_jubatus
			Acerodon_leucotis
			Acerodon_lucifer
			Acerodon_mackloti
			Aethalops_alecto
			Alionycteris_paucidentata
			Aproteles_bulmerae
			Balionycteris_maculata
			Boneia_bidens
			Casinycteris_argynnis
			Chironax_melanocephalus
			Cynopterus_brachyotis
			Cynopterus_horsfieldi
			Cynopterus_nusatenggara
			Cynopterus_sphinx
			Cynopterus_titthaecheilus
			Dobsonia_beauforti
			Dobsonia_chapmani
			Dobsonia_emersa
			Dobsonia_exoleta
			Dobsonia_inermis
			Dobsonia_minor
			Dobsonia_moluccensis
			Dobsonia_pannietensis
			Dobsonia_peroni
			Dobsonia_praedatrix
			Dobsonia_viridis
			Dyacopterus_spadiceus
			Eidolon_dupreanum
			Eidolon_helvum
			Epomophorus_angolensis
			Epomophorus_gambianus
			Epomophorus_grandis
			Epomophorus_labiatus
			Epomophorus_minimus
			Epomophorus_wahlbergi
			Epomops_buettikoferi
			Epomops_dobsoni
			Epomops_franqueti
			Haplonycteris_fischeri
			Harpyionycteris_celebensis
			Harpyionycteris_whiteheadi
			Hypsignathus_monstrosus
			Latidens_salimalii
			Megaerops_ecaudatus
			Megaerops_kusnotoi
			Megaerops_niphanae
			Megaerops_wetmorei
			Micropteropus_intermedius
			Micropteropus_pusillus
			Myonycteris_brachycephala
			Myonycteris_relicta
			Myonycteris_torquata
			Nanonycteris_veldkampi
			Neopteryx_frosti
			Nyctimene_aello
			Nyctimene_albiventer
			Nyctimene_celaeno
			Nyctimene_cephalotes
			Nyctimene_certans
			Nyctimene_cyclotis
			Nyctimene_draconilla
			Nyctimene_major
			Nyctimene_malaitensis
			Nyctimene_masalai
			Nyctimene_minutus
			Nyctimene_rabori
			Nyctimene_robinsoni
			Nyctimene_sanctacrucis
			Nyctimene_vizcaccia
			Otopteropus_cartilagonodus
			Paranyctimene_raptor
			Penthetor_lucasi
			Plerotes_anchietai
			Ptenochirus_jagori
			Ptenochirus_minor
			Pteralopex_acrodonta
			Pteralopex_anceps
			Pteralopex_atrata
			Pteralopex_pulchra
			Pteropus_admiralitatum
			Pteropus_aldabrensis
			Pteropus_alecto
			Pteropus_anetianus
			Pteropus_argentatus
			Pteropus_brunneus
			Pteropus_caniceps
			Pteropus_chrysoproctus
			Pteropus_conspicillatus
			Pteropus_dasymallus
			Pteropus_faunulus
			Pteropus_fundatus
			Pteropus_giganteus
			Pteropus_gilliardi
			Pteropus_griseus
			Pteropus_howensis
			Pteropus_hypomelanus
			Pteropus_insularis
			Pteropus_leucopterus
			Pteropus_livingstonii
			Pteropus_lombocensis
			Pteropus_lylei
			Pteropus_macrotis
			Pteropus_mahaganus
			Pteropus_mariannus
			Pteropus_mearnsi
			Pteropus_melanopogon
			Pteropus_melanotus
			Pteropus_molossinus
			Pteropus_neohibernicus
			Pteropus_niger
			Pteropus_nitendiensis
			Pteropus_ocularis
			Pteropus_ornatus
			Pteropus_personatus
			Pteropus_phaeocephalus
			Pteropus_pilosus
			Pteropus_pohlei
			Pteropus_poliocephalus
			Pteropus_pselaphon
			Pteropus_pumilus
			Pteropus_rayneri
			Pteropus_rodricensis
			Pteropus_rufus
			Pteropus_samoensis
			Pteropus_sanctacrucis
			Pteropus_scapulatus
			Pteropus_seychellensis
			Pteropus_speciosus
			Pteropus_subniger
			Pteropus_temmincki
			Pteropus_tokudae
			Pteropus_tonganus
			Pteropus_tuberculatus
			Pteropus_vampyrus
			Pteropus_vetulus
			Pteropus_voeltzkowi
			Pteropus_woodfordi
			Rousettus_amplexicaudatus
			Rousettus_angolensis
			Rousettus_celebensis
			Rousettus_egyptiacus
			Rousettus_lanosus
			Rousettus_leschenaulti
			Rousettus_madagascariensis
			Rousettus_obliviosus
			Rousettus_spinalatus
			Scotonycteris_ophiodon
			Scotonycteris_zenkeri
			Sphaerias_blanfordi
			Styloctenium_wallacei
			Thoopterus_nigrescens
			Eonycteris_major
			Eonycteris_spelaea
			Macroglossus_minimus
			Macroglossus_sobrinus
			Megaloglossus_woermanni
			Melonycteris_aurantius
			Melonycteris_melanops
			Melonycteris_woodfordi
			Notopteris_macdonaldi
			Syconycteris_australis
			Syconycteris_carolinae
			Syconycteris_hobbit
			Rhinopoma_hardwickei
			Rhinopoma_microphyllum
			Rhinopoma_muscatellum
			Craseonycteris_thonglongyai
			Balantiopteryx_infusca
			Balantiopteryx_io
			Balantiopteryx_plicata
			Centronycteris_maximiliani
			Coleura_afra
			Coleura_seychellensis
			Cormura_brevirostris
			Cyttarops_alecto
			Diclidurus_albus
			Diclidurus_ingens
			Diclidurus_isabellus
			Diclidurus_scutatus
			Emballonura_alecto
			Emballonura_atrata
			Emballonura_beccarii
			Emballonura_dianae
			Emballonura_furax
			Emballonura_monticola
			Emballonura_raffrayana
			Emballonura_semicaudata
			Mosia_nigrescens
			Peropteryx_kappleri
			Peropteryx_leucoptera
			Peropteryx_macrotis
			Rhynchonycteris_naso
			Saccolaimus_flaviventris
			Saccolaimus_mixtus
			Saccolaimus_peli
			Saccolaimus_pluto
			Saccolaimus_saccolaimus
			Saccopteryx_bilineata
			Saccopteryx_canescens
			Saccopteryx_gymnura
			Saccopteryx_leptura
			Taphozous_australis
			Taphozous_georgianus
			Taphozous_hamiltoni
			Taphozous_hildegardeae
			Taphozous_hilli
			Taphozous_kapalgensis
			Taphozous_longimanus
			Taphozous_mauritianus
			Taphozous_melanopogon
			Taphozous_nudiventris
			Taphozous_perforatus
			Taphozous_philippinensis
			Taphozous_theobaldi
			Nycteris_arge
			Nycteris_gambiensis
			Nycteris_grandis
			Nycteris_hispida
			Nycteris_intermedia
			Nycteris_javanica
			Nycteris_macrotis
			Nycteris_major
			Nycteris_nana
			Nycteris_thebaica
			Nycteris_tragata
			Nycteris_woodi
			Cardioderma_cor
			Lavia_frons
			Macroderma_gigas
			Megaderma_lyra
			Megaderma_spasma
			Rhinolophus_acuminatus
			Rhinolophus_adami
			Rhinolophus_affinis
			Rhinolophus_alcyone
			Rhinolophus_anderseni
			Rhinolophus_arcuatus
			Rhinolophus_blasii
			Rhinolophus_borneensis
			Rhinolophus_canuti
			Rhinolophus_capensis
			Rhinolophus_celebensis
			Rhinolophus_clivosus
			Rhinolophus_coelophyllus
			Rhinolophus_cognatus
			Rhinolophus_cornutus
			Rhinolophus_creaghi
			Rhinolophus_darlingi
			Rhinolophus_deckenii
			Rhinolophus_denti
			Rhinolophus_eloquens
			Rhinolophus_euryale
			Rhinolophus_euryotis
			Rhinolophus_ferrumequinum
			Rhinolophus_fumigatus
			Rhinolophus_guineensis
			Rhinolophus_hildebrandti
			Rhinolophus_hipposideros
			Rhinolophus_imaizumii
			Rhinolophus_inops
			Rhinolophus_keyensis
			Rhinolophus_landeri
			Rhinolophus_lepidus
			Rhinolophus_luctus
			Rhinolophus_maclaudi
			Rhinolophus_macrotis
			Rhinolophus_malayanus
			Rhinolophus_marshalli
			Rhinolophus_megaphyllus
			Rhinolophus_mehelyi
			Rhinolophus_mitratus
			Rhinolophus_monoceros
			Rhinolophus_nereis
			Rhinolophus_osgoodi
			Rhinolophus_paradoxolophus
			Rhinolophus_pearsonii
			Rhinolophus_philippinensis
			Rhinolophus_pusillus
			Rhinolophus_rex
			Rhinolophus_robinsoni
			Rhinolophus_rouxii
			Rhinolophus_rufus
			Rhinolophus_sedulus
			Rhinolophus_shameli
			Rhinolophus_silvestris
			Rhinolophus_simplex
			Rhinolophus_simulator
			Rhinolophus_stheno
			Rhinolophus_subbadius
			Rhinolophus_subrufus
			Rhinolophus_swinnyi
			Rhinolophus_thomasi
			Rhinolophus_trifoliatus
			Rhinolophus_virgo
			Rhinolophus_yunanensis
			Anthops_ornatus
			Asellia_patrizii
			Asellia_tridens
			Aselliscus_stoliczkanus
			Aselliscus_tricuspidatus
			Cloeotis_percivali
			Coelops_frithi
			Coelops_hirsutus
			Coelops_robinsoni
			Hipposideros_abae
			Hipposideros_armiger
			Hipposideros_ater
			Hipposideros_beatus
			Hipposideros_bicolor
			Hipposideros_breviceps
			Hipposideros_caffer
			Hipposideros_calcaratus
			Hipposideros_camerunensis
			Hipposideros_cervinus
			Hipposideros_cineraceus
			Hipposideros_commersoni
			Hipposideros_coronatus
			Hipposideros_corynophyllus
			Hipposideros_coxi
			Hipposideros_crumeniferus
			Hipposideros_curtus
			Hipposideros_cyclops
			Hipposideros_diadema
			Hipposideros_dinops
			Hipposideros_doriae
			Hipposideros_dyacorum
			Hipposideros_fuliginosus
			Hipposideros_fulvus
			Hipposideros_galeritus
			Hipposideros_halophyllus
			Hipposideros_inexpectatus
			Hipposideros_jonesi
			Hipposideros_lamottei
			Hipposideros_lankadiva
			Hipposideros_larvatus
			Hipposideros_lekaguli
			Hipposideros_lylei
			Hipposideros_macrobullatus
			Hipposideros_maggietaylorae
			Hipposideros_marisae
			Hipposideros_megalotis
			Hipposideros_muscinus
			Hipposideros_nequam
			Hipposideros_obscurus
			Hipposideros_papua
			Hipposideros_pomona
			Hipposideros_pratti
			Hipposideros_pygmaeus
			Hipposideros_ridleyi
			Hipposideros_ruber
			Hipposideros_sabanus
			Hipposideros_schistaceus
			Hipposideros_semoni
			Hipposideros_speoris
			Hipposideros_stenotis
			Hipposideros_turpis
			Hipposideros_wollastoni
			Paracoelops_megalotis
			Rhinonicteris_aurantia
			Triaenops_furculus
			Triaenops_persicus
			Noctilio_albiventris
			Noctilio_leporinus
			Mormoops_blainvillii
			Mormoops_megalophylla
			Pteronotus_davyi
			Pteronotus_gymnonotus
			Pteronotus_macleayii
			Pteronotus_parnellii
			Pteronotus_personatus
			Pteronotus_quadridens
			Chrotopterus_auritus
			Lonchorhina_aurita
			Lonchorhina_fernandezi
			Lonchorhina_marinkellei
			Lonchorhina_orinocensis
			Macrophyllum_macrophyllum
			Macrotus_californicus
			Macrotus_waterhousii
			Micronycteris_behnii
			Micronycteris_brachyotis
			Micronycteris_daviesi
			Micronycteris_hirsuta
			Micronycteris_megalotis
			Micronycteris_minuta
			Micronycteris_nicefori
			Micronycteris_pusilla
			Micronycteris_schmidtorum
			Micronycteris_sylvestris
			Mimon_bennettii
			Mimon_crenulatum
			Phylloderma_stenops
			Phyllostomus_discolor
			Phyllostomus_elongatus
			Phyllostomus_hastatus
			Phyllostomus_latifolius
			Tonatia_bidens
			Tonatia_brasiliense
			Tonatia_carrikeri
			Tonatia_evotis
			Tonatia_schulzi
			Tonatia_silvicola
			Trachops_cirrhosus
			Vampyrum_spectrum
			Lionycteris_spurrelli
			Lonchophylla_bokermanni
			Lonchophylla_dekeyseri
			Lonchophylla_handleyi
			Lonchophylla_hesperia
			Lonchophylla_mordax
			Lonchophylla_robusta
			Lonchophylla_thomasi
			Platalina_genovensium
			Brachyphylla_cavernarum
			Brachyphylla_nana
			Erophylla_sezekorni
			Phyllonycteris_aphylla
			Phyllonycteris_poeyi
			Anoura_caudifera
			Anoura_cultrata
			Anoura_geoffroyi
			Anoura_latidens
			Choeroniscus_godmani
			Choeroniscus_intermedius
			Choeroniscus_minor
			Choeroniscus_periosus
			Choeronycteris_mexicana
			Glossophaga_commissarisi
			Glossophaga_leachii
			Glossophaga_longirostris
			Glossophaga_morenoi
			Glossophaga_soricina
			Hylonycteris_underwoodi
			Leptonycteris_curasoae
			Leptonycteris_nivalis
			Lichonycteris_obscura
			Monophyllus_plethodon
			Monophyllus_redmani
			Musonycteris_harrisoni
			Scleronycteris_ega
			Carollia_brevicauda
			Carollia_castanea
			Carollia_perspicillata
			Carollia_subrufa
			Rhinophylla_alethina
			Rhinophylla_fischerae
			Rhinophylla_pumilio
			Ametrida_centurio
			Ardops_nichollsi
			Ariteus_flavescens
			Artibeus_amplus
			Artibeus_anderseni
			Artibeus_aztecus
			Artibeus_cinereus
			Artibeus_concolor
			Artibeus_fimbriatus
			Artibeus_fraterculus
			Artibeus_glaucus
			Artibeus_hartii
			Artibeus_hirsutus
			Artibeus_inopinatus
			Artibeus_jamaicensis
			Artibeus_lituratus
			Artibeus_obscurus
			Artibeus_phaeotis
			Artibeus_planirostris
			Artibeus_toltecus
			Centurio_senex
			Chiroderma_doriae
			Chiroderma_improvisum
			Chiroderma_salvini
			Chiroderma_trinitatum
			Chiroderma_villosum
			Ectophylla_alba
			Mesophylla_macconnelli
			Phyllops_falcatus
			Platyrrhinus_aurarius
			Platyrrhinus_brachycephalus
			Platyrrhinus_chocoensis
			Platyrrhinus_dorsalis
			Platyrrhinus_helleri
			Platyrrhinus_infuscus
			Platyrrhinus_lineatus
			Platyrrhinus_recifinus
			Platyrrhinus_umbratus
			Platyrrhinus_vittatus
			Pygoderma_bilabiatum
			Sphaeronycteris_toxophyllum
			Stenoderma_rufum
			Sturnira_aratathomasi
			Sturnira_bidens
			Sturnira_bogotensis
			Sturnira_erythromos
			Sturnira_lilium
			Sturnira_ludovici
			Sturnira_luisi
			Sturnira_magna
			Sturnira_mordax
			Sturnira_nana
			Sturnira_thomasi
			Sturnira_tildae
			Uroderma_bilobatum
			Uroderma_magnirostrum
			Vampyressa_bidens
			Vampyressa_brocki
			Vampyressa_melissa
			Vampyressa_nymphaea
			Vampyressa_pusilla
			Vampyrodes_caraccioli
			Desmodus_rotundus
			Diaemus_youngi
			Diphylla_ecaudata
			Natalus_lepidus
			Natalus_micropus
			Natalus_stramineus
			Natalus_tumidifrons
			Natalus_tumidirostris
			Amorphochilus_schnablii
			Furipterus_horrens
			Thyroptera_discifera
			Thyroptera_tricolor
			Myzopoda_aurita
			Kerivoula_aerosa
			Kerivoula_africana
			Kerivoula_agnella
			Kerivoula_argentata
			Kerivoula_atrox
			Kerivoula_cuprosa
			Kerivoula_eriophora
			Kerivoula_flora
			Kerivoula_hardwickei
			Kerivoula_intermedia
			Kerivoula_jagorii
			Kerivoula_lanosa
			Kerivoula_minuta
			Kerivoula_muscina
			Kerivoula_myrella
			Kerivoula_papillosa
			Kerivoula_papuensis
			Kerivoula_pellucida
			Kerivoula_phalaena
			Kerivoula_picta
			Kerivoula_smithii
			Kerivoula_whiteheadi
			Antrozous_dubiaquercus
			Antrozous_pallidus
			Barbastella_barbastellus
			Barbastella_leucomelas
			Chalinolobus_alboguttatus
			Chalinolobus_argentatus
			Chalinolobus_beatrix
			Chalinolobus_dwyeri
			Chalinolobus_egeria
			Chalinolobus_gleni
			Chalinolobus_gouldii
			Chalinolobus_kenyacola
			Chalinolobus_morio
			Chalinolobus_nigrogriseus
			Chalinolobus_picatus
			Chalinolobus_poensis
			Chalinolobus_superbus
			Chalinolobus_tuberculatus
			Chalinolobus_variegatus
			Eptesicus_baverstocki
			Eptesicus_bobrinskoi
			Eptesicus_bottae
			Eptesicus_brasiliensis
			Eptesicus_brunneus
			Eptesicus_capensis
			Eptesicus_demissus
			Eptesicus_diminutus
			Eptesicus_douglasorum
			Eptesicus_flavescens
			Eptesicus_floweri
			Eptesicus_furinalis
			Eptesicus_fuscus
			Eptesicus_guadeloupensis
			Eptesicus_guineensis
			Eptesicus_hottentotus
			Eptesicus_innoxius
			Eptesicus_kobayashii
			Eptesicus_melckorum
			Eptesicus_nasutus
			Eptesicus_nilssoni
			Eptesicus_pachyotis
			Eptesicus_platyops
			Eptesicus_pumilus
			Eptesicus_regulus
			Eptesicus_rendalli
			Eptesicus_sagittula
			Eptesicus_serotinus
			Eptesicus_somalicus
			Eptesicus_tatei
			Eptesicus_tenuipinnis
			Eptesicus_vulturnus
			Euderma_maculatum
			Eudiscopus_denticulus
			Glischropus_javanus
			Glischropus_tylopus
			Hesperoptenus_blanfordi
			Hesperoptenus_doriae
			Hesperoptenus_gaskelli
			Hesperoptenus_tickelli
			Hesperoptenus_tomesi
			Histiotus_alienus
			Histiotus_macrotus
			Histiotus_montanus
			Histiotus_velatus
			Ia_io
			Idionycteris_phyllotis
			Laephotis_angolensis
			Laephotis_botswanae
			Laephotis_namibensis
			Laephotis_wintoni
			Lasionycteris_noctivagans
			Lasiurus_borealis
			Lasiurus_castaneus
			Lasiurus_cinereus
			Lasiurus_ega
			Lasiurus_egregius
			Lasiurus_intermedius
			Lasiurus_seminolus
			Mimetillus_moloneyi
			Myotis_abei
			Myotis_adversus
			Myotis_aelleni
			Myotis_albescens
			Myotis_altarium
			Myotis_annectans
			Myotis_atacamensis
			Myotis_auriculus
			Myotis_australis
			Myotis_austroriparius
			Myotis_bechsteini
			Myotis_blythii
			Myotis_bocagei
			Myotis_bombinus
			Myotis_brandti
			Myotis_californicus
			Myotis_capaccinii
			Myotis_chiloensis
			Myotis_chinensis
			Myotis_cobanensis
			Myotis_dasycneme
			Myotis_daubentoni
			Myotis_dominicensis
			Myotis_elegans
			Myotis_emarginatus
			Myotis_evotis
			Myotis_findleyi
			Myotis_formosus
			Myotis_fortidens
			Myotis_frater
			Myotis_goudoti
			Myotis_grisescens
			Myotis_hasseltii
			Myotis_horsfieldii
			Myotis_hosonoi
			Myotis_ikonnikovi
			Myotis_insularum
			Myotis_keaysi
			Myotis_keenii
			Myotis_leibii
			Myotis_lesueuri
			Myotis_levis
			Myotis_longipes
			Myotis_lucifugus
			Myotis_macrodactylus
			Myotis_macrotarsus
			Myotis_martiniquensis
			Myotis_milleri
			Myotis_montivagus
			Myotis_morrisi
			Myotis_muricola
			Myotis_myotis
			Myotis_mystacinus
			Myotis_nattereri
			Myotis_nesopolus
			Myotis_nigricans
			Myotis_oreias
			Myotis_oxyotus
			Myotis_ozensis
			Myotis_peninsularis
			Myotis_pequinius
			Myotis_planiceps
			Myotis_pruinosus
			Myotis_ricketti
			Myotis_ridleyi
			Myotis_riparius
			Myotis_rosseti
			Myotis_ruber
			Myotis_schaubi
			Myotis_scotti
			Myotis_seabrai
			Myotis_sicarius
			Myotis_siligorensis
			Myotis_simus
			Myotis_sodalis
			Myotis_stalkeri
			Myotis_thysanodes
			Myotis_tricolor
			Myotis_velifer
			Myotis_vivesi
			Myotis_volans
			Myotis_welwitschii
			Myotis_yesoensis
			Myotis_yumanensis
			Nyctalus_aviator
			Nyctalus_azoreum
			Nyctalus_lasiopterus
			Nyctalus_leisleri
			Nyctalus_montanus
			Nyctalus_noctula
			Nycticeius_balstoni
			Nycticeius_greyii
			Nycticeius_humeralis
			Nycticeius_rueppellii
			Nycticeius_sanborni
			Nycticeius_schlieffeni
			Nyctophilus_arnhemensis
			Nyctophilus_geoffroyi
			Nyctophilus_gouldi
			Nyctophilus_heran
			Nyctophilus_microdon
			Nyctophilus_microtis
			Nyctophilus_timoriensis
			Nyctophilus_walkeri
			Otonycteris_hemprichii
			Pharotis_imogene
			Philetor_brachypterus
			Pipistrellus_aegyptius
			Pipistrellus_aero
			Pipistrellus_affinis
			Pipistrellus_anchietai
			Pipistrellus_anthonyi
			Pipistrellus_arabicus
			Pipistrellus_ariel
			Pipistrellus_babu
			Pipistrellus_bodenheimeri
			Pipistrellus_cadornae
			Pipistrellus_ceylonicus
			Pipistrellus_circumdatus
			Pipistrellus_coromandra
			Pipistrellus_crassulus
			Pipistrellus_cuprosus
			Pipistrellus_dormeri
			Pipistrellus_eisentrauti
			Pipistrellus_endoi
			Pipistrellus_hesperus
			Pipistrellus_imbricatus
			Pipistrellus_inexspectatus
			Pipistrellus_javanicus
			Pipistrellus_joffrei
			Pipistrellus_kitcheneri
			Pipistrellus_kuhlii
			Pipistrellus_lophurus
			Pipistrellus_macrotis
			Pipistrellus_maderensis
			Pipistrellus_mimus
			Pipistrellus_minahassae
			Pipistrellus_mordax
			Pipistrellus_musciculus
			Pipistrellus_nanulus
			Pipistrellus_nanus
			Pipistrellus_nathusii
			Pipistrellus_paterculus
			Pipistrellus_peguensis
			Pipistrellus_permixtus
			Pipistrellus_petersi
			Pipistrellus_pipistrellus
			Pipistrellus_pulveratus
			Pipistrellus_rueppelli
			Pipistrellus_rusticus
			Pipistrellus_savii
			Pipistrellus_societatis
			Pipistrellus_stenopterus
			Pipistrellus_sturdeei
			Pipistrellus_subflavus
			Pipistrellus_tasmaniensis
			Pipistrellus_tenuis
			Plecotus_auritus
			Plecotus_austriacus
			Plecotus_mexicanus
			Plecotus_rafinesquii
			Plecotus_taivanus
			Plecotus_teneriffae
			Plecotus_townsendii
			Rhogeessa_alleni
			Rhogeessa_genowaysi
			Rhogeessa_gracilis
			Rhogeessa_minutilla
			Rhogeessa_mira
			Rhogeessa_parvula
			Rhogeessa_tumida
			Scotoecus_albofuscus
			Scotoecus_hirundo
			Scotoecus_pallidus
			Scotomanes_emarginatus
			Scotomanes_ornatus
			Scotophilus_borbonicus
			Scotophilus_celebensis
			Scotophilus_dinganii
			Scotophilus_heathi
			Scotophilus_kuhlii
			Scotophilus_leucogaster
			Scotophilus_nigrita
			Scotophilus_nux
			Scotophilus_robustus
			Scotophilus_viridis
			Tylonycteris_pachypus
			Tylonycteris_robustula
			Vespertilio_murinus
			Vespertilio_superans
			Harpiocephalus_harpia
			Murina_aenea
			Murina_aurata
			Murina_cyclotis
			Murina_florium
			Murina_fusca
			Murina_grisea
			Murina_huttoni
			Murina_leucogaster
			Murina_puta
			Murina_rozendaali
			Murina_silvatica
			Murina_suilla
			Murina_tenebrosa
			Murina_tubinaris
			Murina_ussuriensis
			Miniopterus_australis
			Miniopterus_fraterculus
			Miniopterus_fuscus
			Miniopterus_inflatus
			Miniopterus_magnater
			Miniopterus_minor
			Miniopterus_pusillus
			Miniopterus_robustior
			Miniopterus_schreibersi
			Miniopterus_tristis
			Tomopeas_ravus
			Mystacina_robusta
			Mystacina_tuberculata
			Chaerephon_aloysiisabaudiae
			Chaerephon_ansorgei
			Chaerephon_bemmeleni
			Chaerephon_bivittata
			Chaerephon_chapini
			Chaerephon_gallagheri
			Chaerephon_jobensis
			Chaerephon_johorensis
			Chaerephon_major
			Chaerephon_nigeriae
			Chaerephon_plicata
			Chaerephon_pumila
			Chaerephon_russata
			Cheiromeles_torquatus
			Eumops_auripendulus
			Eumops_bonariensis
			Eumops_dabbenei
			Eumops_glaucinus
			Eumops_hansae
			Eumops_maurus
			Eumops_perotis
			Eumops_underwoodi
			Molossops_abrasus
			Molossops_aequatorianus
			Molossops_greenhalli
			Molossops_mattogrossensis
			Molossops_neglectus
			Molossops_planirostris
			Molossops_temminckii
			Molossus_ater
			Molossus_bondae
			Molossus_molossus
			Molossus_pretiosus
			Molossus_sinaloae
			Mops_brachypterus
			Mops_condylurus
			Mops_congicus
			Mops_demonstrator
			Mops_midas
			Mops_mops
			Mops_nanulus
			Mops_niangarae
			Mops_niveiventer
			Mops_petersoni
			Mops_sarasinorum
			Mops_spurrelli
			Mops_thersites
			Mops_trevori
			Mormopterus_acetabulosus
			Mormopterus_beccarii
			Mormopterus_doriae
			Mormopterus_jugularis
			Mormopterus_kalinowskii
			Mormopterus_minutus
			Mormopterus_norfolkensis
			Mormopterus_petrophilus
			Mormopterus_phrudus
			Mormopterus_planiceps
			Mormopterus_setiger
			Myopterus_daubentonii
			Myopterus_whitleyi
			Nyctinomops_aurispinosus
			Nyctinomops_femorosaccus
			Nyctinomops_laticaudatus
			Nyctinomops_macrotis
			Otomops_formosus
			Otomops_martiensseni
			Otomops_papuensis
			Otomops_secundus
			Otomops_wroughtoni
			Promops_centralis
			Promops_nasutus
			Tadarida_aegyptiaca
			Tadarida_australis
			Tadarida_brasiliensis
			Tadarida_espiritosantensis
			Tadarida_fulminans
			Tadarida_lobata
			Tadarida_teniotis
			Tadarida_ventralis);
		@{ $speciesList{Primates} } = qw(Allocebus_trichotis
			Cheirogaleus_major
			Cheirogaleus_medius
			Microcebus_coquereli
			Microcebus_murinus
			Microcebus_rufus
			Phaner_furcifer
			Eulemur_coronatus
			Eulemur_fulvus
			Eulemur_macaco
			Eulemur_mongoz
			Eulemur_rubriventer
			Hapalemur_aureus
			Hapalemur_griseus
			Hapalemur_simus
			Lemur_catta
			Varecia_variegata
			Lepilemur_dorsalis
			Lepilemur_edwardsi
			Lepilemur_leucopus
			Lepilemur_microdon
			Lepilemur_mustelinus
			Lepilemur_ruficaudatus
			Lepilemur_septentrionalis
			Avahi_laniger
			Indri_indri
			Propithecus_diadema
			Propithecus_tattersalli
			Propithecus_verreauxi
			Daubentonia_madagascariensis
			Arctocebus_aureus
			Arctocebus_calabarensis
			Loris_tardigradus
			Nycticebus_coucang
			Nycticebus_pygmaeus
			Perodicticus_potto
			Euoticus_elegantulus
			Euoticus_pallidus
			Galago_alleni
			Galago_gallarum
			Galago_matschiei
			Galago_moholi
			Galago_senegalensis
			Galagoides_demidoff
			Galagoides_zanzibaricus
			Otolemur_crassicaudatus
			Otolemur_garnettii
			Tarsius_bancanus
			Tarsius_dianae
			Tarsius_pumilus
			Tarsius_spectrum
			Tarsius_syrichta
			Callimico_goeldii
			Callithrix_argentata
			Callithrix_aurita
			Callithrix_flaviceps
			Callithrix_geoffroyi
			Callithrix_humeralifera
			Callithrix_jacchus
			Callithrix_kuhlii
			Callithrix_penicillata
			Callithrix_pygmaea
			Leontopithecus_caissara
			Leontopithecus_chrysomelas
			Leontopithecus_chrysopygus
			Leontopithecus_rosalia
			Saguinus_bicolor
			Saguinus_fuscicollis
			Saguinus_geoffroyi
			Saguinus_imperator
			Saguinus_inustus
			Saguinus_labiatus
			Saguinus_leucopus
			Saguinus_midas
			Saguinus_mystax
			Saguinus_nigricollis
			Saguinus_oedipus
			Saguinus_tripartitus
			Alouatta_belzebul
			Alouatta_caraya
			Alouatta_coibensis
			Alouatta_fusca
			Alouatta_palliata
			Alouatta_pigra
			Alouatta_sara
			Alouatta_seniculus
			Aotus_azarai
			Aotus_brumbacki
			Aotus_hershkovitzi
			Aotus_infulatus
			Aotus_lemurinus
			Aotus_miconax
			Aotus_nancymaae
			Aotus_nigriceps
			Aotus_trivirgatus
			Aotus_vociferans
			Ateles_belzebuth
			Ateles_chamek
			Ateles_fusciceps
			Ateles_geoffroyi
			Ateles_marginatus
			Ateles_paniscus
			Brachyteles_arachnoides
			Lagothrix_flavicauda
			Lagothrix_lagotricha
			Callicebus_brunneus
			Callicebus_caligatus
			Callicebus_cinerascens
			Callicebus_cupreus
			Callicebus_donacophilus
			Callicebus_dubius
			Callicebus_hoffmannsi
			Callicebus_modestus
			Callicebus_moloch
			Callicebus_oenanthe
			Callicebus_olallae
			Callicebus_personatus
			Callicebus_torquatus
			Cebus_albifrons
			Cebus_apella
			Cebus_capucinus
			Cebus_olivaceus
			Saimiri_boliviensis
			Saimiri_oerstedii
			Saimiri_sciureus
			Saimiri_ustus
			Saimiri_vanzolinii
			Cacajao_calvus
			Cacajao_melanocephalus
			Chiropotes_albinasus
			Chiropotes_satanas
			Pithecia_aequatorialis
			Pithecia_albicans
			Pithecia_irrorata
			Pithecia_monachus
			Pithecia_pithecia
			Allenopithecus_nigroviridis
			Cercocebus_agilis
			Cercocebus_galeritus
			Cercocebus_torquatus
			Cercopithecus_ascanius
			Cercopithecus_campbelli
			Cercopithecus_cephus
			Cercopithecus_diana
			Cercopithecus_dryas
			Cercopithecus_erythrogaster
			Cercopithecus_erythrotis
			Cercopithecus_hamlyni
			Cercopithecus_lhoesti
			Cercopithecus_mitis
			Cercopithecus_mona
			Cercopithecus_neglectus
			Cercopithecus_nictitans
			Cercopithecus_petaurista
			Cercopithecus_pogonias
			Cercopithecus_preussi
			Cercopithecus_sclateri
			Cercopithecus_solatus
			Cercopithecus_wolfi
			Chlorocebus_aethiops
			Erythrocebus_patas
			Lophocebus_albigena
			Macaca_arctoides
			Macaca_assamensis
			Macaca_cyclopis
			Macaca_fascicularis
			Macaca_fuscata
			Macaca_maura
			Macaca_mulatta
			Macaca_nemestrina
			Macaca_nigra
			Macaca_ochreata
			Macaca_radiata
			Macaca_silenus
			Macaca_sinica
			Macaca_sylvanus
			Macaca_thibetana
			Macaca_tonkeana
			Mandrillus_leucophaeus
			Mandrillus_sphinx
			Miopithecus_talapoin
			Papio_hamadryas
			Theropithecus_gelada
			Colobus_angolensis
			Colobus_guereza
			Colobus_polykomos
			Colobus_satanas
			Nasalis_concolor
			Nasalis_larvatus
			Presbytis_comata
			Presbytis_femoralis
			Presbytis_frontata
			Presbytis_hosei
			Presbytis_melalophos
			Presbytis_potenziani
			Presbytis_rubicunda
			Presbytis_thomasi
			Procolobus_badius
			Procolobus_pennantii
			Procolobus_preussi
			Procolobus_rufomitratus
			Procolobus_verus
			Pygathrix_avunculus
			Pygathrix_bieti
			Pygathrix_brelichi
			Pygathrix_nemaeus
			Pygathrix_roxellana
			Semnopithecus_entellus
			Trachypithecus_auratus
			Trachypithecus_cristatus
			Trachypithecus_francoisi
			Trachypithecus_geei
			Trachypithecus_johnii
			Trachypithecus_obscurus
			Trachypithecus_phayrei
			Trachypithecus_pileatus
			Trachypithecus_vetulus
			Hylobates_agilis
			Hylobates_concolor
			Hylobates_gabriellae
			Hylobates_hoolock
			Hylobates_klossii
			Hylobates_lar
			Hylobates_leucogenys
			Hylobates_moloch
			Hylobates_muelleri
			Hylobates_pileatus
			Hylobates_syndactylus
			Gorilla_gorilla
			Homo_sapiens
			Pan_paniscus
			Pan_troglodytes
			Pongo_pygmaeus);
		@{ $speciesList{Carnivora} } = qw(Alopex_lagopus
			Atelocynus_microtis
			Canis_adustus
			Canis_aureus
			Canis_latrans
			Canis_lupus
			Canis_mesomelas
			Canis_rufus
			Canis_simensis
			Cerdocyon_thous
			Chrysocyon_brachyurus
			Cuon_alpinus
			Dusicyon_australis
			Lycaon_pictus
			Nyctereutes_procyonoides
			Otocyon_megalotis
			Pseudalopex_culpaeus
			Pseudalopex_griseus
			Pseudalopex_gymnocercus
			Pseudalopex_sechurae
			Pseudalopex_vetulus
			Speothos_venaticus
			Urocyon_cinereoargenteus
			Urocyon_littoralis
			Vulpes_bengalensis
			Vulpes_cana
			Vulpes_chama
			Vulpes_corsac
			Vulpes_ferrilata
			Vulpes_pallida
			Vulpes_rueppellii
			Vulpes_velox
			Vulpes_vulpes
			Vulpes_zerda
			Acinonyx_jubatus
			Caracal_caracal
			Catopuma_badia
			Catopuma_temminckii
			Felis_bieti
			Felis_chaus
			Felis_margarita
			Felis_nigripes
			Felis_silvestris
			Herpailurus_yaguarondi
			Leopardus_pardalis
			Leopardus_tigrinus
			Leopardus_wiedii
			Leptailurus_serval
			Lynx_canadensis
			Lynx_lynx
			Lynx_pardinus
			Lynx_rufus
			Oncifelis_colocolo
			Oncifelis_geoffroyi
			Oncifelis_guigna
			Oreailurus_jacobita
			Otocolobus_manul
			Prionailurus_bengalensis
			Prionailurus_planiceps
			Prionailurus_rubiginosus
			Prionailurus_viverrinus
			Profelis_aurata
			Puma_concolor
			Neofelis_nebulosa
			Panthera_leo
			Panthera_onca
			Panthera_pardus
			Panthera_tigris
			Pardofelis_marmorata
			Uncia_uncia
			Galidia_elegans
			Galidictis_fasciata
			Galidictis_grandidieri
			Mungotictis_decemlineata
			Salanoia_concolor
			Atilax_paludinosus
			Bdeogale_crassicauda
			Bdeogale_jacksoni
			Bdeogale_nigripes
			Crossarchus_alexandri
			Crossarchus_ansorgei
			Crossarchus_obscurus
			Cynictis_penicillata
			Dologale_dybowskii
			Galerella_flavescens
			Galerella_pulverulenta
			Galerella_sanguinea
			Galerella_swalius
			Helogale_hirtula
			Helogale_parvula
			Herpestes_brachyurus
			Herpestes_edwardsii
			Herpestes_ichneumon
			Herpestes_javanicus
			Herpestes_naso
			Herpestes_palustris
			Herpestes_semitorquatus
			Herpestes_smithii
			Herpestes_urva
			Herpestes_vitticollis
			Ichneumia_albicauda
			Liberiictis_kuhni
			Mungos_gambianus
			Mungos_mungo
			Paracynictis_selousi
			Rhynchogale_melleri
			Suricata_suricatta
			Crocuta_crocuta
			Hyaena_hyaena
			Parahyaena_brunnea
			Proteles_cristatus
			Amblonyx_cinereus
			Aonyx_capensis
			Aonyx_congicus
			Enhydra_lutris
			Lontra_canadensis
			Lontra_felina
			Lontra_longicaudis
			Lontra_provocax
			Lutra_lutra
			Lutra_maculicollis
			Lutra_sumatrana
			Lutrogale_perspicillata
			Pteronura_brasiliensis
			Arctonyx_collaris
			Meles_meles
			Melogale_everetti
			Melogale_moschata
			Melogale_orientalis
			Melogale_personata
			Mydaus_javanensis
			Mydaus_marchei
			Mellivora_capensis
			Conepatus_chinga
			Conepatus_humboldtii
			Conepatus_leuconotus
			Conepatus_mesoleucus
			Conepatus_semistriatus
			Mephitis_macroura
			Mephitis_mephitis
			Spilogale_putorius
			Spilogale_pygmaea
			Eira_barbara
			Galictis_cuja
			Galictis_vittata
			Gulo_gulo
			Ictonyx_libyca
			Ictonyx_striatus
			Lyncodon_patagonicus
			Martes_americana
			Martes_flavigula
			Martes_foina
			Martes_gwatkinsii
			Martes_martes
			Martes_melampus
			Martes_pennanti
			Martes_zibellina
			Mustela_africana
			Mustela_altaica
			Mustela_erminea
			Mustela_eversmannii
			Mustela_felipei
			Mustela_frenata
			Mustela_kathiah
			Mustela_lutreola
			Mustela_lutreolina
			Mustela_nigripes
			Mustela_nivalis
			Mustela_nudipes
			Mustela_putorius
			Mustela_sibirica
			Mustela_strigidorsa
			Mustela_vison
			Poecilogale_albinucha
			Vormela_peregusna
			Taxidea_taxus
			Odobenus_rosmarus
			Arctocephalus_australis
			Arctocephalus_forsteri
			Arctocephalus_galapagoensis
			Arctocephalus_gazella
			Arctocephalus_philippii
			Arctocephalus_pusillus
			Arctocephalus_townsendi
			Arctocephalus_tropicalis
			Callorhinus_ursinus
			Eumetopias_jubatus
			Neophoca_cinerea
			Otaria_byronia
			Phocarctos_hookeri
			Zalophus_californianus
			Cystophora_cristata
			Erignathus_barbatus
			Halichoerus_grypus
			Hydrurga_leptonyx
			Leptonychotes_weddellii
			Lobodon_carcinophagus
			Mirounga_angustirostris
			Mirounga_leonina
			Monachus_monachus
			Monachus_schauinslandi
			Monachus_tropicalis
			Ommatophoca_rossii
			Phoca_caspica
			Phoca_fasciata
			Phoca_groenlandica
			Phoca_hispida
			Phoca_largha
			Phoca_sibirica
			Phoca_vitulina
			Bassaricyon_alleni
			Bassaricyon_beddardi
			Bassaricyon_gabbii
			Bassaricyon_lasius
			Bassaricyon_pauli
			Potos_flavus
			Bassariscus_astutus
			Bassariscus_sumichrasti
			Nasua_narica
			Nasua_nasua
			Nasuella_olivacea
			Procyon_cancrivorus
			Procyon_gloveralleni
			Procyon_insularis
			Procyon_lotor
			Procyon_maynardi
			Procyon_minor
			Procyon_pygmaeus
			Ailuropoda_melanoleuca
			Ailurus_fulgens
			Helarctos_malayanus
			Melursus_ursinus
			Tremarctos_ornatus
			Ursus_americanus
			Ursus_arctos
			Ursus_maritimus
			Ursus_thibetanus
			Cryptoprocta_ferox
			Eupleres_goudotii
			Fossa_fossana
			Chrotogale_owstoni
			Cynogale_bennettii
			Diplogale_hosei
			Hemigalus_derbyanus
			Nandinia_binotata
			Arctictis_binturong
			Arctogalidia_trivirgata
			Macrogalidia_musschenbroekii
			Paguma_larvata
			Paradoxurus_hermaphroditus
			Paradoxurus_jerdoni
			Paradoxurus_zeylonensis
			Civettictis_civetta
			Genetta_abyssinica
			Genetta_angolensis
			Genetta_genetta
			Genetta_johnstoni
			Genetta_maculata
			Genetta_servalina
			Genetta_thierryi
			Genetta_tigrina
			Genetta_victoriae
			Osbornictis_piscivora
			Poiana_richardsonii
			Prionodon_linsang
			Prionodon_pardicolor
			Viverra_civettina
			Viverra_megaspila
			Viverra_tangalunga
			Viverra_zibetha
			Viverricula_indica);
		@{ $speciesList{Cetacea} } = qw(Balaena_mysticetus
			Eubalaena_australis
			Eubalaena_glacialis
			Balaenoptera_acutorostrata
			Balaenoptera_borealis
			Balaenoptera_edeni
			Balaenoptera_musculus
			Balaenoptera_physalus
			Megaptera_novaeangliae
			Eschrichtius_robustus
			Caperea_marginata
			Cephalorhynchus_commersonii
			Cephalorhynchus_eutropia
			Cephalorhynchus_heavisidii
			Cephalorhynchus_hectori
			Delphinus_delphis
			Feresa_attenuata
			Globicephala_macrorhynchus
			Globicephala_melas
			Grampus_griseus
			Lagenodelphis_hosei
			Lagenorhynchus_acutus
			Lagenorhynchus_albirostris
			Lagenorhynchus_australis
			Lagenorhynchus_cruciger
			Lagenorhynchus_obliquidens
			Lagenorhynchus_obscurus
			Lissodelphis_borealis
			Lissodelphis_peronii
			Orcaella_brevirostris
			Orcinus_orca
			Peponocephala_electra
			Pseudorca_crassidens
			Sotalia_fluviatilis
			Sousa_chinensis
			Sousa_teuszii
			Stenella_attenuata
			Stenella_clymene
			Stenella_coeruleoalba
			Stenella_frontalis
			Stenella_longirostris
			Steno_bredanensis
			Tursiops_truncatus
			Delphinapterus_leucas
			Monodon_monoceros
			Australophocaena_dioptrica
			Neophocaena_phocaenoides
			Phocoena_phocoena
			Phocoena_sinus
			Phocoena_spinipinnis
			Phocoenoides_dalli
			Kogia_breviceps
			Kogia_simus
			Physeter_catodon
			Inia_geoffrensis
			Lipotes_vexillifer
			Platanista_gangetica
			Platanista_minor
			Pontoporia_blainvillei
			Berardius_arnuxii
			Berardius_bairdii
			Hyperoodon_ampullatus
			Hyperoodon_planifrons
			Indopacetus_pacificus
			Mesoplodon_bidens
			Mesoplodon_bowdoini
			Mesoplodon_carlhubbsi
			Mesoplodon_densirostris
			Mesoplodon_europaeus
			Mesoplodon_ginkgodens
			Mesoplodon_grayi
			Mesoplodon_hectori
			Mesoplodon_layardii
			Mesoplodon_mirus
			Mesoplodon_peruvianus
			Mesoplodon_stejnegeri
			Tasmacetus_shepherdi
			Ziphius_cavirostris);
		@{ $speciesList{Sirenia} } = qw(Dugong_dugon
			Hydrodamalis_gigas
			Trichechus_inunguis
			Trichechus_manatus
			Trichechus_senegalensis);
		@{ $speciesList{Proboscidea} } = qw(Elephas_maximus
			Loxodonta_africana);
		@{ $speciesList{Perissodactyla} } = qw(Equus_asinus
			Equus_burchellii
			Equus_caballus
			Equus_grevyi
			Equus_hemionus
			Equus_kiang
			Equus_onager
			Equus_quagga
			Equus_zebra
			Tapirus_bairdii
			Tapirus_indicus
			Tapirus_pinchaque
			Tapirus_terrestris
			Ceratotherium_simum
			Dicerorhinus_sumatrensis
			Diceros_bicornis
			Rhinoceros_sondaicus
			Rhinoceros_unicornis);
		@{ $speciesList{Hyracoidea} } = qw(Dendrohyrax_arboreus
			Dendrohyrax_dorsalis
			Dendrohyrax_validus
			Heterohyrax_antineae
			Heterohyrax_brucei
			Procavia_capensis);
		@{ $speciesList{Tubulidentata} } = qw(Orycteropus_afer);
		@{ $speciesList{Artiodactyla} } = qw(Babyrousa_babyrussa
			Phacochoerus_aethiopicus
			Phacochoerus_africanus
			Hylochoerus_meinertzhageni
			Potamochoerus_larvatus
			Potamochoerus_porcus
			Sus_barbatus
			Sus_bucculentus
			Sus_cebifrons
			Sus_celebensis
			Sus_heureni
			Sus_philippensis
			Sus_salvanius
			Sus_scrofa
			Sus_timoriensis
			Sus_verrucosus
			Catagonus_wagneri
			Pecari_tajacu
			Tayassu_pecari
			Hexaprotodon_liberiensis
			Hexaprotodon_madagascariensis
			Hippopotamus_amphibius
			Hippopotamus_lemerlei
			Camelus_bactrianus
			Camelus_dromedarius
			Lama_glama
			Lama_guanicoe
			Lama_pacos
			Vicugna_vicugna
			Hyemoschus_aquaticus
			Moschiola_meminna
			Tragulus_javanicus
			Tragulus_napu
			Giraffa_camelopardalis
			Okapia_johnstoni
			Moschus_berezovskii
			Moschus_chrysogaster
			Moschus_fuscus
			Moschus_moschiferus
			Axis_axis
			Axis_calamianensis
			Axis_kuhlii
			Axis_porcinus
			Cervus_albirostris
			Cervus_alfredi
			Cervus_duvaucelii
			Cervus_elaphus
			Cervus_eldii
			Cervus_mariannus
			Cervus_nippon
			Cervus_schomburgki
			Cervus_timorensis
			Cervus_unicolor
			Dama_dama
			Dama_mesopotamica
			Elaphurus_davidianus
			Hydropotes_inermis
			Elaphodus_cephalophus
			Muntiacus_atherodes
			Muntiacus_crinifrons
			Muntiacus_feae
			Muntiacus_gongshanensis
			Muntiacus_muntjak
			Muntiacus_reevesi
			Alces_alces
			Blastocerus_dichotomus
			Capreolus_capreolus
			Capreolus_pygargus
			Hippocamelus_antisensis
			Hippocamelus_bisulcus
			Mazama_americana
			Mazama_bricenii
			Mazama_chunyi
			Mazama_gouazoupira
			Mazama_nana
			Mazama_rufina
			Odocoileus_hemionus
			Odocoileus_virginianus
			Ozotoceros_bezoarticus
			Pudu_mephistophiles
			Pudu_puda
			Rangifer_tarandus
			Antilocapra_americana
			Aepyceros_melampus
			Alcelaphus_buselaphus
			Connochaetes_gnou
			Connochaetes_taurinus
			Damaliscus_hunteri
			Damaliscus_lunatus
			Damaliscus_pygargus
			Sigmoceros_lichtensteinii
			Ammodorcas_clarkei
			Antidorcas_marsupialis
			Antilope_cervicapra
			Dorcatragus_megalotis
			Gazella_arabica
			Gazella_bennettii
			Gazella_bilkis
			Gazella_cuvieri
			Gazella_dama
			Gazella_dorcas
			Gazella_gazella
			Gazella_granti
			Gazella_leptoceros
			Gazella_rufifrons
			Gazella_rufina
			Gazella_saudiya
			Gazella_soemmerringii
			Gazella_spekei
			Gazella_subgutturosa
			Gazella_thomsonii
			Litocranius_walleri
			Madoqua_guentheri
			Madoqua_kirkii
			Madoqua_piacentinii
			Madoqua_saltiana
			Neotragus_batesi
			Neotragus_moschatus
			Neotragus_pygmaeus
			Oreotragus_oreotragus
			Ourebia_ourebi
			Pantholops_hodgsonii
			Procapra_gutturosa
			Procapra_picticaudata
			Procapra_przewalskii
			Raphicerus_campestris
			Raphicerus_melanotis
			Raphicerus_sharpei
			Saiga_tatarica
			Bison_bison
			Bison_bonasus
			Bos_frontalis
			Bos_grunniens
			Bos_javanicus
			Bos_sauveli
			Bos_taurus
			Boselaphus_tragocamelus
			Bubalus_bubalis
			Bubalus_depressicornis
			Bubalus_mephistopheles
			Bubalus_mindorensis
			Bubalus_quarlesi
			Syncerus_caffer
			Taurotragus_derbianus
			Taurotragus_oryx
			Tetracerus_quadricornis
			Tragelaphus_angasii
			Tragelaphus_buxtoni
			Tragelaphus_eurycerus
			Tragelaphus_imberbis
			Tragelaphus_scriptus
			Tragelaphus_spekii
			Tragelaphus_strepsiceros
			Ammotragus_lervia
			Budorcas_taxicolor
			Capra_caucasica
			Capra_cylindricornis
			Capra_falconeri
			Capra_hircus
			Capra_ibex
			Capra_nubiana
			Capra_pyrenaica
			Capra_sibirica
			Capra_walie
			Hemitragus_hylocrius
			Hemitragus_jayakari
			Hemitragus_jemlahicus
			Naemorhedus_baileyi
			Naemorhedus_caudatus
			Naemorhedus_crispus
			Naemorhedus_goral
			Naemorhedus_sumatraensis
			Naemorhedus_swinhoei
			Oreamnos_americanus
			Ovibos_moschatus
			Ovis_ammon
			Ovis_aries
			Ovis_canadensis
			Ovis_dalli
			Ovis_nivicola
			Ovis_vignei
			Pseudois_nayaur
			Pseudois_schaeferi
			Rupicapra_pyrenaica
			Rupicapra_rupicapra
			Cephalophus_adersi
			Cephalophus_callipygus
			Cephalophus_dorsalis
			Cephalophus_harveyi
			Cephalophus_jentinki
			Cephalophus_leucogaster
			Cephalophus_maxwellii
			Cephalophus_monticola
			Cephalophus_natalensis
			Cephalophus_niger
			Cephalophus_nigrifrons
			Cephalophus_ogilbyi
			Cephalophus_rubidus
			Cephalophus_rufilatus
			Cephalophus_silvicultor
			Cephalophus_spadix
			Cephalophus_weynsi
			Cephalophus_zebra
			Sylvicapra_grimmia
			Addax_nasomaculatus
			Hippotragus_equinus
			Hippotragus_leucophaeus
			Hippotragus_niger
			Oryx_dammah
			Oryx_gazella
			Oryx_leucoryx
			Pelea_capreolus
			Kobus_ellipsiprymnus
			Kobus_kob
			Kobus_leche
			Kobus_megaceros
			Kobus_vardonii
			Redunca_arundinum
			Redunca_fulvorufula
			Redunca_redunca);
		@{ $speciesList{Pholidota} } = qw(Manis_crassicaudata
			Manis_gigantea
			Manis_javanica
			Manis_pentadactyla
			Manis_temminckii
			Manis_tetradactyla
			Manis_tricuspis);
		@{ $speciesList{Rodentia} } = qw(Aplodontia_rufa
			Ammospermophilus_harrisii
			Ammospermophilus_insularis
			Ammospermophilus_interpres
			Ammospermophilus_leucurus
			Ammospermophilus_nelsoni
			Atlantoxerus_getulus
			Callosciurus_adamsi
			Callosciurus_albescens
			Callosciurus_baluensis
			Callosciurus_caniceps
			Callosciurus_erythraeus
			Callosciurus_finlaysonii
			Callosciurus_inornatus
			Callosciurus_melanogaster
			Callosciurus_nigrovittatus
			Callosciurus_notatus
			Callosciurus_orestes
			Callosciurus_phayrei
			Callosciurus_prevostii
			Callosciurus_pygerythrus
			Callosciurus_quinquestriatus
			Cynomys_gunnisoni
			Cynomys_leucurus
			Cynomys_ludovicianus
			Cynomys_mexicanus
			Cynomys_parvidens
			Dremomys_everetti
			Dremomys_lokriah
			Dremomys_pernyi
			Dremomys_pyrrhomerus
			Dremomys_rufigenis
			Epixerus_ebii
			Epixerus_wilsoni
			Exilisciurus_concinnus
			Exilisciurus_exilis
			Exilisciurus_whiteheadi
			Funambulus_layardi
			Funambulus_palmarum
			Funambulus_pennantii
			Funambulus_sublineatus
			Funambulus_tristriatus
			Funisciurus_anerythrus
			Funisciurus_bayonii
			Funisciurus_carruthersi
			Funisciurus_congicus
			Funisciurus_isabella
			Funisciurus_lemniscatus
			Funisciurus_leucogenys
			Funisciurus_pyrropus
			Funisciurus_substriatus
			Glyphotes_simus
			Heliosciurus_gambianus
			Heliosciurus_mutabilis
			Heliosciurus_punctatus
			Heliosciurus_rufobrachium
			Heliosciurus_ruwenzorii
			Heliosciurus_undulatus
			Hyosciurus_heinrichi
			Hyosciurus_ileile
			Lariscus_hosei
			Lariscus_insignis
			Lariscus_niobe
			Lariscus_obscurus
			Marmota_baibacina
			Marmota_bobak
			Marmota_broweri
			Marmota_caligata
			Marmota_camtschatica
			Marmota_caudata
			Marmota_flaviventris
			Marmota_himalayana
			Marmota_marmota
			Marmota_menzbieri
			Marmota_monax
			Marmota_olympus
			Marmota_sibirica
			Marmota_vancouverensis
			Menetes_berdmorei
			Microsciurus_alfari
			Microsciurus_flaviventer
			Microsciurus_mimulus
			Microsciurus_santanderensis
			Myosciurus_pumilio
			Nannosciurus_melanotis
			Paraxerus_alexandri
			Paraxerus_boehmi
			Paraxerus_cepapi
			Paraxerus_cooperi
			Paraxerus_flavovittis
			Paraxerus_lucifer
			Paraxerus_ochraceus
			Paraxerus_palliatus
			Paraxerus_poensis
			Paraxerus_vexillarius
			Paraxerus_vincenti
			Prosciurillus_abstrusus
			Prosciurillus_leucomus
			Prosciurillus_murinus
			Prosciurillus_weberi
			Protoxerus_aubinnii
			Protoxerus_stangeri
			Ratufa_affinis
			Ratufa_bicolor
			Ratufa_indica
			Ratufa_macroura
			Rheithrosciurus_macrotis
			Rhinosciurus_laticaudatus
			Rubrisciurus_rubriventer
			Sciurillus_pusillus
			Sciurotamias_davidianus
			Sciurotamias_forresti
			Sciurus_aberti
			Sciurus_aestuans
			Sciurus_alleni
			Sciurus_anomalus
			Sciurus_arizonensis
			Sciurus_aureogaster
			Sciurus_carolinensis
			Sciurus_colliaei
			Sciurus_deppei
			Sciurus_flammifer
			Sciurus_gilvigularis
			Sciurus_granatensis
			Sciurus_griseus
			Sciurus_ignitus
			Sciurus_igniventris
			Sciurus_lis
			Sciurus_nayaritensis
			Sciurus_niger
			Sciurus_oculatus
			Sciurus_pucheranii
			Sciurus_pyrrhinus
			Sciurus_richmondi
			Sciurus_sanborni
			Sciurus_spadiceus
			Sciurus_stramineus
			Sciurus_variegatoides
			Sciurus_vulgaris
			Sciurus_yucatanensis
			Spermophilopsis_leptodactylus
			Spermophilus_adocetus
			Spermophilus_alashanicus
			Spermophilus_annulatus
			Spermophilus_armatus
			Spermophilus_atricapillus
			Spermophilus_beecheyi
			Spermophilus_beldingi
			Spermophilus_brunneus
			Spermophilus_canus
			Spermophilus_citellus
			Spermophilus_columbianus
			Spermophilus_dauricus
			Spermophilus_elegans
			Spermophilus_erythrogenys
			Spermophilus_franklinii
			Spermophilus_fulvus
			Spermophilus_lateralis
			Spermophilus_madrensis
			Spermophilus_major
			Spermophilus_mexicanus
			Spermophilus_mohavensis
			Spermophilus_mollis
			Spermophilus_musicus
			Spermophilus_parryii
			Spermophilus_perotensis
			Spermophilus_pygmaeus
			Spermophilus_relictus
			Spermophilus_richardsonii
			Spermophilus_saturatus
			Spermophilus_spilosoma
			Spermophilus_suslicus
			Spermophilus_tereticaudus
			Spermophilus_townsendii
			Spermophilus_tridecemlineatus
			Spermophilus_undulatus
			Spermophilus_variegatus
			Spermophilus_washingtoni
			Spermophilus_xanthoprymnus
			Sundasciurus_brookei
			Sundasciurus_davensis
			Sundasciurus_fraterculus
			Sundasciurus_hippurus
			Sundasciurus_hoogstraali
			Sundasciurus_jentinki
			Sundasciurus_juvencus
			Sundasciurus_lowii
			Sundasciurus_mindanensis
			Sundasciurus_moellendorffi
			Sundasciurus_philippinensis
			Sundasciurus_rabori
			Sundasciurus_samarensis
			Sundasciurus_steerii
			Sundasciurus_tenuis
			Syntheosciurus_brochus
			Tamias_alpinus
			Tamias_amoenus
			Tamias_bulleri
			Tamias_canipes
			Tamias_cinereicollis
			Tamias_dorsalis
			Tamias_durangae
			Tamias_merriami
			Tamias_minimus
			Tamias_obscurus
			Tamias_ochrogenys
			Tamias_palmeri
			Tamias_panamintinus
			Tamias_quadrimaculatus
			Tamias_quadrivittatus
			Tamias_ruficaudus
			Tamias_rufus
			Tamias_senex
			Tamias_sibiricus
			Tamias_siskiyou
			Tamias_sonomae
			Tamias_speciosus
			Tamias_striatus
			Tamias_townsendii
			Tamias_umbrinus
			Tamiasciurus_douglasii
			Tamiasciurus_hudsonicus
			Tamiasciurus_mearnsi
			Tamiops_macclellandi
			Tamiops_maritimus
			Tamiops_rodolphei
			Tamiops_swinhoei
			Xerus_erythropus
			Xerus_inauris
			Xerus_princeps
			Xerus_rutilus
			Aeretes_melanopterus
			Aeromys_tephromelas
			Aeromys_thomasi
			Belomys_pearsonii
			Biswamoyopterus_biswasi
			Eupetaurus_cinereus
			Glaucomys_sabrinus
			Glaucomys_volans
			Hylopetes_alboniger
			Hylopetes_baberi
			Hylopetes_bartelsi
			Hylopetes_fimbriatus
			Hylopetes_lepidus
			Hylopetes_nigripes
			Hylopetes_phayrei
			Hylopetes_sipora
			Hylopetes_spadiceus
			Hylopetes_winstoni
			Iomys_horsfieldii
			Iomys_sipora
			Petaurillus_emiliae
			Petaurillus_hosei
			Petaurillus_kinlochii
			Petaurista_alborufus
			Petaurista_elegans
			Petaurista_leucogenys
			Petaurista_magnificus
			Petaurista_nobilis
			Petaurista_petaurista
			Petaurista_philippensis
			Petaurista_xanthotis
			Petinomys_crinitus
			Petinomys_fuscocapillus
			Petinomys_genibarbis
			Petinomys_hageni
			Petinomys_lugens
			Petinomys_sagitta
			Petinomys_setosus
			Petinomys_vordermanni
			Pteromys_momonga
			Pteromys_volans
			Pteromyscus_pulverulentus
			Trogopterus_xanthipes
			Castor_canadensis
			Castor_fiber
			Geomys_arenarius
			Geomys_bursarius
			Geomys_personatus
			Geomys_pinetis
			Geomys_tropicalis
			Orthogeomys_cavator
			Orthogeomys_cherriei
			Orthogeomys_cuniculus
			Orthogeomys_dariensis
			Orthogeomys_grandis
			Orthogeomys_heterodus
			Orthogeomys_hispidus
			Orthogeomys_lanius
			Orthogeomys_matagalpae
			Orthogeomys_thaeleri
			Orthogeomys_underwoodi
			Pappogeomys_alcorni
			Pappogeomys_bulleri
			Pappogeomys_castanops
			Pappogeomys_fumosus
			Pappogeomys_gymnurus
			Pappogeomys_merriami
			Pappogeomys_neglectus
			Pappogeomys_tylorhinus
			Pappogeomys_zinseri
			Thomomys_bottae
			Thomomys_bulbivorus
			Thomomys_clusius
			Thomomys_idahoensis
			Thomomys_mazama
			Thomomys_monticola
			Thomomys_talpoides
			Thomomys_townsendii
			Thomomys_umbrinus
			Zygogeomys_trichopus
			Dipodomys_agilis
			Dipodomys_californicus
			Dipodomys_compactus
			Dipodomys_deserti
			Dipodomys_elator
			Dipodomys_elephantinus
			Dipodomys_gravipes
			Dipodomys_heermanni
			Dipodomys_ingens
			Dipodomys_insularis
			Dipodomys_margaritae
			Dipodomys_merriami
			Dipodomys_microps
			Dipodomys_nelsoni
			Dipodomys_nitratoides
			Dipodomys_ordii
			Dipodomys_panamintinus
			Dipodomys_phillipsii
			Dipodomys_spectabilis
			Dipodomys_stephensi
			Dipodomys_venustus
			Microdipodops_megacephalus
			Microdipodops_pallidus
			Heteromys_anomalus
			Heteromys_australis
			Heteromys_desmarestianus
			Heteromys_gaumeri
			Heteromys_goldmani
			Heteromys_nelsoni
			Heteromys_oresterus
			Liomys_adspersus
			Liomys_irroratus
			Liomys_pictus
			Liomys_salvini
			Liomys_spectabilis
			Chaetodipus_arenarius
			Chaetodipus_artus
			Chaetodipus_baileyi
			Chaetodipus_californicus
			Chaetodipus_fallax
			Chaetodipus_formosus
			Chaetodipus_goldmani
			Chaetodipus_hispidus
			Chaetodipus_intermedius
			Chaetodipus_lineatus
			Chaetodipus_nelsoni
			Chaetodipus_penicillatus
			Chaetodipus_pernix
			Chaetodipus_spinatus
			Perognathus_alticola
			Perognathus_amplus
			Perognathus_fasciatus
			Perognathus_flavescens
			Perognathus_flavus
			Perognathus_inornatus
			Perognathus_longimembris
			Perognathus_merriami
			Perognathus_parvus
			Perognathus_xanthanotus
			Allactaga_balikunica
			Allactaga_bullata
			Allactaga_elater
			Allactaga_euphratica
			Allactaga_firouzi
			Allactaga_hotsoni
			Allactaga_major
			Allactaga_severtzovi
			Allactaga_sibirica
			Allactaga_tetradactyla
			Allactaga_vinogradovi
			Allactodipus_bobrinskii
			Pygeretmus_platyurus
			Pygeretmus_pumilio
			Pygeretmus_shitkovi
			Cardiocranius_paradoxus
			Salpingotus_crassicauda
			Salpingotus_heptneri
			Salpingotus_kozlovi
			Salpingotus_michaelis
			Salpingotus_pallidus
			Salpingotus_thomasi
			Dipus_sagitta
			Eremodipus_lichtensteini
			Jaculus_blanfordi
			Jaculus_jaculus
			Jaculus_orientalis
			Jaculus_turcmenicus
			Stylodipus_andrewsi
			Stylodipus_sungorus
			Stylodipus_telum
			Euchoreutes_naso
			Paradipus_ctenodactylus
			Sicista_armenica
			Sicista_betulina
			Sicista_caucasica
			Sicista_caudata
			Sicista_concolor
			Sicista_kazbegica
			Sicista_kluchorica
			Sicista_napaea
			Sicista_pseudonapaea
			Sicista_severtzovi
			Sicista_strandi
			Sicista_subtilis
			Sicista_tianshanica
			Eozapus_setchuanus
			Napaeozapus_insignis
			Zapus_hudsonius
			Zapus_princeps
			Zapus_trinotatus
			Alticola_albicauda
			Alticola_argentatus
			Alticola_barakshin
			Alticola_lemminus
			Alticola_macrotis
			Alticola_montosa
			Alticola_roylei
			Alticola_semicanus
			Alticola_stoliczkanus
			Alticola_stracheyi
			Alticola_strelzowi
			Alticola_tuvinicus
			Arborimus_albipes
			Arborimus_longicaudus
			Arborimus_pomo
			Arvicola_sapidus
			Arvicola_terrestris
			Blanfordimys_afghanus
			Blanfordimys_bucharicus
			Chionomys_gud
			Chionomys_nivalis
			Chionomys_roberti
			Clethrionomys_californicus
			Clethrionomys_centralis
			Clethrionomys_gapperi
			Clethrionomys_glareolus
			Clethrionomys_rufocanus
			Clethrionomys_rutilus
			Clethrionomys_sikotanensis
			Dicrostonyx_exsul
			Dicrostonyx_groenlandicus
			Dicrostonyx_hudsonius
			Dicrostonyx_kilangmiutak
			Dicrostonyx_nelsoni
			Dicrostonyx_nunatakensis
			Dicrostonyx_richardsoni
			Dicrostonyx_rubricatus
			Dicrostonyx_torquatus
			Dicrostonyx_unalascensis
			Dicrostonyx_vinogradovi
			Dinaromys_bogdanovi
			Ellobius_alaicus
			Ellobius_fuscocapillus
			Ellobius_lutescens
			Ellobius_talpinus
			Ellobius_tancrei
			Eolagurus_luteus
			Eolagurus_przewalskii
			Eothenomys_chinensis
			Eothenomys_custos
			Eothenomys_eva
			Eothenomys_inez
			Eothenomys_melanogaster
			Eothenomys_olitor
			Eothenomys_proditor
			Eothenomys_regulus
			Eothenomys_shanseius
			Hyperacrius_fertilis
			Hyperacrius_wynnei
			Lagurus_lagurus
			Lasiopodomys_brandtii
			Lasiopodomys_fuscus
			Lasiopodomys_mandarinus
			Lemmiscus_curtatus
			Lemmus_amurensis
			Lemmus_lemmus
			Lemmus_sibiricus
			Microtus_abbreviatus
			Microtus_agrestis
			Microtus_arvalis
			Microtus_bavaricus
			Microtus_breweri
			Microtus_cabrerae
			Microtus_californicus
			Microtus_canicaudus
			Microtus_chrotorrhinus
			Microtus_daghestanicus
			Microtus_duodecimcostatus
			Microtus_evoronensis
			Microtus_felteni
			Microtus_fortis
			Microtus_gerbei
			Microtus_gregalis
			Microtus_guatemalensis
			Microtus_guentheri
			Microtus_hyperboreus
			Microtus_irani
			Microtus_irene
			Microtus_juldaschi
			Microtus_kermanensis
			Microtus_kirgisorum
			Microtus_leucurus
			Microtus_limnophilus
			Microtus_longicaudus
			Microtus_lusitanicus
			Microtus_majori
			Microtus_maximowiczii
			Microtus_mexicanus
			Microtus_middendorffi
			Microtus_miurus
			Microtus_mongolicus
			Microtus_montanus
			Microtus_montebelli
			Microtus_mujanensis
			Microtus_multiplex
			Microtus_nasarovi
			Microtus_oaxacensis
			Microtus_obscurus
			Microtus_ochrogaster
			Microtus_oeconomus
			Microtus_oregoni
			Microtus_pennsylvanicus
			Microtus_pinetorum
			Microtus_quasiater
			Microtus_richardsoni
			Microtus_rossiaemeridionalis
			Microtus_sachalinensis
			Microtus_savii
			Microtus_schelkovnikovi
			Microtus_sikimensis
			Microtus_socialis
			Microtus_subterraneus
			Microtus_tatricus
			Microtus_thomasi
			Microtus_townsendii
			Microtus_transcaspicus
			Microtus_umbrosus
			Microtus_xanthognathus
			Myopus_schisticolor
			Neofiber_alleni
			Ondatra_zibethicus
			Phaulomys_andersoni
			Phaulomys_smithii
			Phenacomys_intermedius
			Phenacomys_ungava
			Proedromys_bedfordi
			Prometheomys_schaposchnikowi
			Synaptomys_borealis
			Synaptomys_cooperi
			Volemys_clarkei
			Volemys_kikuchii
			Volemys_millicens
			Volemys_musseri
			Calomyscus_bailwardi
			Calomyscus_baluchi
			Calomyscus_hotsoni
			Calomyscus_mystax
			Calomyscus_tsolovi
			Calomyscus_urartensis
			Allocricetulus_curtatus
			Allocricetulus_eversmanni
			Cansumys_canus
			Cricetulus_alticola
			Cricetulus_barabensis
			Cricetulus_kamensis
			Cricetulus_longicaudatus
			Cricetulus_migratorius
			Cricetulus_sokolovi
			Cricetus_cricetus
			Mesocricetus_auratus
			Mesocricetus_brandti
			Mesocricetus_newtoni
			Mesocricetus_raddei
			Phodopus_campbelli
			Phodopus_roborovskii
			Phodopus_sungorus
			Tscherskia_triton
			Beamys_hindei
			Beamys_major
			Cricetomys_emini
			Cricetomys_gambianus
			Saccostomus_campestris
			Saccostomus_mearnsi
			Dendromus_insignis
			Dendromus_kahuziensis
			Dendromus_kivu
			Dendromus_lovati
			Dendromus_melanotis
			Dendromus_mesomelas
			Dendromus_messorius
			Dendromus_mystacalis
			Dendromus_nyikae
			Dendromus_oreas
			Dendromus_vernayi
			Dendroprionomys_rousseloti
			Deomys_ferrugineus
			Leimacomys_buettneri
			Malacothrix_typica
			Megadendromus_nikolausi
			Prionomys_batesi
			Steatomys_caurinus
			Steatomys_cuppedius
			Steatomys_jacksoni
			Steatomys_krebsii
			Steatomys_parvus
			Steatomys_pratensis
			Ammodillus_imbellis
			Brachiones_przewalskii
			Desmodilliscus_braueri
			Desmodillus_auricularis
			Gerbillurus_paeba
			Gerbillurus_setzeri
			Gerbillurus_tytonis
			Gerbillurus_vallinus
			Gerbillus_acticola
			Gerbillus_agag
			Gerbillus_allenbyi
			Gerbillus_amoenus
			Gerbillus_andersoni
			Gerbillus_aquilus
			Gerbillus_bilensis
			Gerbillus_bonhotei
			Gerbillus_bottai
			Gerbillus_brockmani
			Gerbillus_burtoni
			Gerbillus_campestris
			Gerbillus_cheesmani
			Gerbillus_cosensi
			Gerbillus_dalloni
			Gerbillus_dasyurus
			Gerbillus_diminutus
			Gerbillus_dongolanus
			Gerbillus_dunni
			Gerbillus_famulus
			Gerbillus_floweri
			Gerbillus_garamantis
			Gerbillus_gerbillus
			Gerbillus_gleadowi
			Gerbillus_grobbeni
			Gerbillus_harwoodi
			Gerbillus_henleyi
			Gerbillus_hesperinus
			Gerbillus_hoogstraali
			Gerbillus_jamesi
			Gerbillus_juliani
			Gerbillus_latastei
			Gerbillus_lowei
			Gerbillus_mackillingini
			Gerbillus_maghrebi
			Gerbillus_mauritaniae
			Gerbillus_mesopotamiae
			Gerbillus_muriculus
			Gerbillus_nancillus
			Gerbillus_nanus
			Gerbillus_nigeriae
			Gerbillus_occiduus
			Gerbillus_percivali
			Gerbillus_perpallidus
			Gerbillus_poecilops
			Gerbillus_principulus
			Gerbillus_pulvinatus
			Gerbillus_pusillus
			Gerbillus_pyramidum
			Gerbillus_quadrimaculatus
			Gerbillus_riggenbachi
			Gerbillus_rosalinda
			Gerbillus_ruberrimus
			Gerbillus_simoni
			Gerbillus_somalicus
			Gerbillus_stigmonyx
			Gerbillus_syrticus
			Gerbillus_tarabuli
			Gerbillus_vivax
			Gerbillus_watersi
			Meriones_arimalius
			Meriones_chengi
			Meriones_crassus
			Meriones_dahli
			Meriones_hurrianae
			Meriones_libycus
			Meriones_meridianus
			Meriones_persicus
			Meriones_rex
			Meriones_sacramenti
			Meriones_shawi
			Meriones_tamariscinus
			Meriones_tristrami
			Meriones_unguiculatus
			Meriones_vinogradovi
			Meriones_zarudnyi
			Microdillus_peeli
			Pachyuromys_duprasi
			Psammomys_obesus
			Psammomys_vexillaris
			Rhombomys_opimus
			Sekeetamys_calurus
			Tatera_afra
			Tatera_boehmi
			Tatera_brantsii
			Tatera_guineae
			Tatera_inclusa
			Tatera_indica
			Tatera_kempi
			Tatera_leucogaster
			Tatera_nigricauda
			Tatera_phillipsi
			Tatera_robusta
			Tatera_valida
			Taterillus_arenarius
			Taterillus_congicus
			Taterillus_emini
			Taterillus_gracilis
			Taterillus_harringtoni
			Taterillus_lacustris
			Taterillus_petteri
			Taterillus_pygargus
			Lophiomys_imhausi
			Abditomys_latidens
			Acomys_cahirinus
			Acomys_cilicicus
			Acomys_cinerasceus
			Acomys_ignitus
			Acomys_kempi
			Acomys_louisae
			Acomys_minous
			Acomys_mullah
			Acomys_nesiotes
			Acomys_percivali
			Acomys_russatus
			Acomys_spinosissimus
			Acomys_subspinosus
			Acomys_wilsoni
			Aethomys_bocagei
			Aethomys_chrysophilus
			Aethomys_granti
			Aethomys_hindei
			Aethomys_kaiseri
			Aethomys_namaquensis
			Aethomys_nyikae
			Aethomys_silindensis
			Aethomys_stannarius
			Aethomys_thomasi
			Anisomys_imitator
			Anonymomys_mindorensis
			Apodemus_agrarius
			Apodemus_alpicola
			Apodemus_argenteus
			Apodemus_arianus
			Apodemus_chevrieri
			Apodemus_draco
			Apodemus_flavicollis
			Apodemus_fulvipectus
			Apodemus_gurkha
			Apodemus_hermonensis
			Apodemus_hyrcanicus
			Apodemus_latronum
			Apodemus_mystacinus
			Apodemus_peninsulae
			Apodemus_ponticus
			Apodemus_rusiges
			Apodemus_semotus
			Apodemus_speciosus
			Apodemus_sylvaticus
			Apodemus_uralensis
			Apodemus_wardi
			Apomys_abrae
			Apomys_datae
			Apomys_hylocoetes
			Apomys_insignis
			Apomys_littoralis
			Apomys_microdon
			Apomys_musculus
			Apomys_sacobianus
			Archboldomys_luzonensis
			Arvicanthis_abyssinicus
			Arvicanthis_blicki
			Arvicanthis_nairobae
			Arvicanthis_niloticus
			Arvicanthis_somalicus
			Bandicota_bengalensis
			Bandicota_indica
			Bandicota_savilei
			Batomys_dentatus
			Batomys_granti
			Batomys_salomonseni
			Berylmys_berdmorei
			Berylmys_bowersi
			Berylmys_mackenziei
			Berylmys_manipulus
			Bullimus_bagobus
			Bullimus_luzonicus
			Bunomys_andrewsi
			Bunomys_chrysocomus
			Bunomys_coelestis
			Bunomys_fratrorum
			Bunomys_heinrichi
			Bunomys_penitus
			Bunomys_prolatus
			Canariomys_tamarani
			Carpomys_melanurus
			Carpomys_phaeurus
			Celaenomys_silaceus
			Chiromyscus_chiropus
			Chiropodomys_calamianensis
			Chiropodomys_gliroides
			Chiropodomys_karlkoopmani
			Chiropodomys_major
			Chiropodomys_muroides
			Chiropodomys_pusillus
			Chiruromys_forbesi
			Chiruromys_lamia
			Chiruromys_vates
			Chrotomys_gonzalesi
			Chrotomys_mindorensis
			Chrotomys_whiteheadi
			Coccymys_albidens
			Coccymys_ruemmleri
			Colomys_goslingi
			Conilurus_albipes
			Conilurus_penicillatus
			Coryphomys_buehleri
			Crateromys_australis
			Crateromys_paulus
			Crateromys_schadenbergi
			Cremnomys_blanfordi
			Cremnomys_cutchicus
			Cremnomys_elvira
			Crossomys_moncktoni
			Crunomys_celebensis
			Crunomys_fallax
			Crunomys_melanius
			Crunomys_rabori
			Dacnomys_millardi
			Dasymys_foxi
			Dasymys_incomtus
			Dasymys_montanus
			Dasymys_nudipes
			Dasymys_rufulus
			Dephomys_defua
			Dephomys_eburnea
			Desmomys_harringtoni
			Diomys_crumpi
			Diplothrix_legatus
			Echiothrix_leucura
			Eropeplus_canus
			Golunda_ellioti
			Grammomys_aridulus
			Grammomys_buntingi
			Grammomys_caniceps
			Grammomys_cometes
			Grammomys_dolichurus
			Grammomys_dryas
			Grammomys_gigas
			Grammomys_ibeanus
			Grammomys_macmillani
			Grammomys_minnae
			Grammomys_rutilans
			Hadromys_humei
			Haeromys_margarettae
			Haeromys_minahassae
			Haeromys_pusillus
			Hapalomys_delacouri
			Hapalomys_longicaudatus
			Heimyscus_fumosus
			Hybomys_basilii
			Hybomys_eisentrauti
			Hybomys_lunaris
			Hybomys_planifrons
			Hybomys_trivirgatus
			Hybomys_univittatus
			Hydromys_chrysogaster
			Hydromys_habbema
			Hydromys_hussoni
			Hydromys_neobrittanicus
			Hydromys_shawmayeri
			Hylomyscus_aeta
			Hylomyscus_alleni
			Hylomyscus_baeri
			Hylomyscus_carillus
			Hylomyscus_denniae
			Hylomyscus_parvus
			Hylomyscus_stella
			Hyomys_dammermani
			Hyomys_goliath
			Kadarsanomys_sodyi
			Komodomys_rintjanus
			Lamottemys_okuensis
			Leggadina_forresti
			Leggadina_lakedownensis
			Lemniscomys_barbarus
			Lemniscomys_bellieri
			Lemniscomys_griselda
			Lemniscomys_hoogstraali
			Lemniscomys_linulus
			Lemniscomys_macculus
			Lemniscomys_mittendorfi
			Lemniscomys_rosalia
			Lemniscomys_roseveari
			Lemniscomys_striatus
			Lenomys_meyeri
			Lenothrix_canus
			Leopoldamys_edwardsi
			Leopoldamys_neilli
			Leopoldamys_sabanus
			Leopoldamys_siporanus
			Leporillus_apicalis
			Leporillus_conditor
			Leptomys_elegans
			Leptomys_ernstmayri
			Leptomys_signatus
			Limnomys_sibuanus
			Lophuromys_cinereus
			Lophuromys_flavopunctatus
			Lophuromys_luteogaster
			Lophuromys_medicaudatus
			Lophuromys_melanonyx
			Lophuromys_nudicaudus
			Lophuromys_rahmi
			Lophuromys_sikapusi
			Lophuromys_woosnami
			Lorentzimys_nouhuysi
			Macruromys_elegans
			Macruromys_major
			Malacomys_cansdalei
			Malacomys_edwardsi
			Malacomys_longipes
			Malacomys_lukolelae
			Malacomys_verschureni
			Mallomys_aroaensis
			Mallomys_gunung
			Mallomys_istapantap
			Mallomys_rothschildi
			Malpaisomys_insularis
			Margaretamys_beccarii
			Margaretamys_elegans
			Margaretamys_parvus
			Mastomys_angolensis
			Mastomys_coucha
			Mastomys_erythroleucus
			Mastomys_hildebrandtii
			Mastomys_natalensis
			Mastomys_pernanus
			Mastomys_shortridgei
			Mastomys_verheyeni
			Maxomys_alticola
			Maxomys_baeodon
			Maxomys_bartelsii
			Maxomys_dollmani
			Maxomys_hellwaldii
			Maxomys_hylomyoides
			Maxomys_inas
			Maxomys_inflatus
			Maxomys_moi
			Maxomys_musschenbroekii
			Maxomys_ochraceiventer
			Maxomys_pagensis
			Maxomys_panglima
			Maxomys_rajah
			Maxomys_surifer
			Maxomys_wattsi
			Maxomys_whiteheadi
			Mayermys_ellermani
			Melasmothrix_naso
			Melomys_aerosus
			Melomys_bougainville
			Melomys_burtoni
			Melomys_capensis
			Melomys_cervinipes
			Melomys_fellowsi
			Melomys_fraterculus
			Melomys_gracilis
			Melomys_lanosus
			Melomys_leucogaster
			Melomys_levipes
			Melomys_lorentzii
			Melomys_mollis
			Melomys_moncktoni
			Melomys_obiensis
			Melomys_platyops
			Melomys_rattoides
			Melomys_rubex
			Melomys_rubicola
			Melomys_rufescens
			Melomys_spechti
			Mesembriomys_gouldii
			Mesembriomys_macrurus
			Microhydromys_musseri
			Microhydromys_richardsoni
			Micromys_minutus
			Millardia_gleadowi
			Millardia_kathleenae
			Millardia_kondana
			Millardia_meltada
			Muriculus_imberbis
			Mus_baoulei
			Mus_booduga
			Mus_bufo
			Mus_callewaerti
			Mus_caroli
			Mus_cervicolor
			Mus_cookii
			Mus_crociduroides
			Mus_famulus
			Mus_fernandoni
			Mus_goundae
			Mus_haussa
			Mus_indutus
			Mus_kasaicus
			Mus_macedonicus
			Mus_mahomet
			Mus_mattheyi
			Mus_mayori
			Mus_minutoides
			Mus_musculoides
			Mus_musculus
			Mus_neavei
			Mus_orangiae
			Mus_oubanguii
			Mus_pahari
			Mus_phillipsi
			Mus_platythrix
			Mus_saxicola
			Mus_setulosus
			Mus_setzeri
			Mus_shortridgei
			Mus_sorella
			Mus_spicilegus
			Mus_spretus
			Mus_tenellus
			Mus_terricolor
			Mus_triton
			Mus_vulcani
			Mylomys_dybowskii
			Myomys_albipes
			Myomys_daltoni
			Myomys_derooi
			Myomys_fumatus
			Myomys_ruppi
			Myomys_verreauxii
			Myomys_yemeni
			Neohydromys_fuscus
			Nesokia_bunnii
			Nesokia_indica
			Niviventer_andersoni
			Niviventer_brahma
			Niviventer_confucianus
			Niviventer_coxingi
			Niviventer_cremoriventer
			Niviventer_culturatus
			Niviventer_eha
			Niviventer_excelsior
			Niviventer_fulvescens
			Niviventer_hinpoon
			Niviventer_langbianis
			Niviventer_lepturus
			Niviventer_niviventer
			Niviventer_rapit
			Niviventer_tenaster
			Notomys_alexis
			Notomys_amplus
			Notomys_aquilo
			Notomys_cervinus
			Notomys_fuscus
			Notomys_longicaudatus
			Notomys_macrotis
			Notomys_mitchellii
			Notomys_mordax
			Oenomys_hypoxanthus
			Oenomys_ornatus
			Palawanomys_furvus
			Papagomys_armandvillei
			Papagomys_theodorverhoeveni
			Parahydromys_asper
			Paraleptomys_rufilatus
			Paraleptomys_wilhelmina
			Paruromys_dominator
			Paruromys_ursinus
			Paulamys_naso
			Pelomys_campanae
			Pelomys_fallax
			Pelomys_hopkinsi
			Pelomys_isseli
			Pelomys_minor
			Phloeomys_cumingi
			Phloeomys_pallidus
			Pithecheir_melanurus
			Pithecheir_parvus
			Pogonomelomys_bruijni
			Pogonomelomys_mayeri
			Pogonomelomys_sevia
			Pogonomys_championi
			Pogonomys_loriae
			Pogonomys_macrourus
			Pogonomys_sylvestris
			Praomys_delectorum
			Praomys_hartwigi
			Praomys_jacksoni
			Praomys_minor
			Praomys_misonnei
			Praomys_morio
			Praomys_mutoni
			Praomys_rostratus
			Praomys_tullbergi
			Pseudohydromys_murinus
			Pseudohydromys_occidentalis
			Pseudomys_albocinereus
			Pseudomys_apodemoides
			Pseudomys_australis
			Pseudomys_bolami
			Pseudomys_chapmani
			Pseudomys_delicatulus
			Pseudomys_desertor
			Pseudomys_fieldi
			Pseudomys_fumeus
			Pseudomys_fuscus
			Pseudomys_glaucus
			Pseudomys_gouldii
			Pseudomys_gracilicaudatus
			Pseudomys_hermannsburgensis
			Pseudomys_higginsi
			Pseudomys_johnsoni
			Pseudomys_laborifex
			Pseudomys_nanus
			Pseudomys_novaehollandiae
			Pseudomys_occidentalis
			Pseudomys_oralis
			Pseudomys_patrius
			Pseudomys_pilligaensis
			Pseudomys_praeconis
			Pseudomys_shortridgei
			Rattus_adustus
			Rattus_annandalei
			Rattus_argentiventer
			Rattus_baluensis
			Rattus_bontanus
			Rattus_burrus
			Rattus_colletti
			Rattus_elaphinus
			Rattus_enganus
			Rattus_everetti
			Rattus_exulans
			Rattus_feliceus
			Rattus_foramineus
			Rattus_fuscipes
			Rattus_giluwensis
			Rattus_hainaldi
			Rattus_hoffmanni
			Rattus_hoogerwerfi
			Rattus_jobiensis
			Rattus_koopmani
			Rattus_korinchi
			Rattus_leucopus
			Rattus_losea
			Rattus_lugens
			Rattus_lutreolus
			Rattus_macleari
			Rattus_marmosurus
			Rattus_mindorensis
			Rattus_mollicomulus
			Rattus_montanus
			Rattus_mordax
			Rattus_morotaiensis
			Rattus_nativitatis
			Rattus_nitidus
			Rattus_norvegicus
			Rattus_novaeguineae
			Rattus_osgoodi
			Rattus_palmarum
			Rattus_pelurus
			Rattus_praetor
			Rattus_ranjiniae
			Rattus_rattus
			Rattus_sanila
			Rattus_sikkimensis
			Rattus_simalurensis
			Rattus_sordidus
			Rattus_steini
			Rattus_stoicus
			Rattus_tanezumi
			Rattus_tawitawiensis
			Rattus_timorensis
			Rattus_tiomanicus
			Rattus_tunneyi
			Rattus_turkestanicus
			Rattus_villosissimus
			Rattus_xanthurus
			Rhabdomys_pumilio
			Rhynchomys_isarogensis
			Rhynchomys_soricoides
			Solomys_ponceleti
			Solomys_salamonis
			Solomys_salebrosus
			Solomys_sapientis
			Solomys_spriggsarum
			Spelaeomys_florensis
			Srilankamys_ohiensis
			Stenocephalemys_albocaudata
			Stenocephalemys_griseicauda
			Stenomys_ceramicus
			Stenomys_niobe
			Stenomys_richardsoni
			Stenomys_vandeuseni
			Stenomys_verecundus
			Stochomys_longicaudatus
			Sundamys_infraluteus
			Sundamys_maxi
			Sundamys_muelleri
			Taeromys_arcuatus
			Taeromys_callitrichus
			Taeromys_celebensis
			Taeromys_hamatus
			Taeromys_punicans
			Taeromys_taerae
			Tarsomys_apoensis
			Tarsomys_echinatus
			Tateomys_macrocercus
			Tateomys_rhinogradoides
			Thallomys_loringi
			Thallomys_nigricauda
			Thallomys_paedulcus
			Thallomys_shortridgei
			Thamnomys_kempi
			Thamnomys_venustus
			Tokudaia_muenninki
			Tokudaia_osimensis
			Tryphomys_adustus
			Uranomys_ruddi
			Uromys_anak
			Uromys_caudimaculatus
			Uromys_hadrourus
			Uromys_imperator
			Uromys_neobritanicus
			Uromys_porculus
			Uromys_rex
			Vandeleuria_nolthenii
			Vandeleuria_oleracea
			Vernaya_fulva
			Xenuromys_barbatus
			Xeromys_myoides
			Zelotomys_hildegardeae
			Zelotomys_woosnami
			Zyzomys_argurus
			Zyzomys_maini
			Zyzomys_palatilis
			Zyzomys_pedunculatus
			Zyzomys_woodwardi
			Myospalax_aspalax
			Myospalax_epsilanus
			Myospalax_fontanierii
			Myospalax_myospalax
			Myospalax_psilurus
			Myospalax_rothschildi
			Myospalax_smithii
			Mystromys_albicaudatus
			Brachytarsomys_albicauda
			Brachyuromys_betsileoensis
			Brachyuromys_ramirohitra
			Eliurus_majori
			Eliurus_minor
			Eliurus_myoxinus
			Eliurus_penicillatus
			Eliurus_tanala
			Eliurus_webbi
			Gymnuromys_roberti
			Hypogeomys_antimena
			Macrotarsomys_bastardi
			Macrotarsomys_ingens
			Nesomys_rufus
			Otomys_anchietae
			Otomys_angoniensis
			Otomys_denti
			Otomys_irroratus
			Otomys_laminatus
			Otomys_maximus
			Otomys_occidentalis
			Otomys_saundersiae
			Otomys_sloggetti
			Otomys_tropicalis
			Otomys_typus
			Otomys_unisulcatus
			Parotomys_brantsii
			Parotomys_littledalei
			Delanymys_brooksi
			Petromyscus_barbouri
			Petromyscus_collinus
			Petromyscus_monticularis
			Petromyscus_shortridgei
			Platacanthomys_lasiurus
			Typhlomys_chapensis
			Typhlomys_cinereus
			Cannomys_badius
			Rhizomys_pruinosus
			Rhizomys_sinensis
			Rhizomys_sumatrensis
			Tachyoryctes_ankoliae
			Tachyoryctes_annectens
			Tachyoryctes_audax
			Tachyoryctes_daemon
			Tachyoryctes_macrocephalus
			Tachyoryctes_naivashae
			Tachyoryctes_rex
			Tachyoryctes_ruandae
			Tachyoryctes_ruddi
			Tachyoryctes_spalacinus
			Tachyoryctes_splendens
			Abrawayaomys_ruschii
			Aepeomys_fuscatus
			Aepeomys_lugens
			Akodon_aerosus
			Akodon_affinis
			Akodon_albiventer
			Akodon_azarae
			Akodon_bogotensis
			Akodon_boliviensis
			Akodon_budini
			Akodon_cursor
			Akodon_dayi
			Akodon_dolores
			Akodon_fumeus
			Akodon_hershkovitzi
			Akodon_illuteus
			Akodon_iniscatus
			Akodon_juninensis
			Akodon_kempi
			Akodon_kofordi
			Akodon_lanosus
			Akodon_latebricola
			Akodon_lindberghi
			Akodon_longipilis
			Akodon_mansoensis
			Akodon_markhami
			Akodon_mimus
			Akodon_molinae
			Akodon_mollis
			Akodon_neocenus
			Akodon_nigrita
			Akodon_olivaceus
			Akodon_orophilus
			Akodon_puer
			Akodon_sanborni
			Akodon_sanctipaulensis
			Akodon_serrensis
			Akodon_siberiae
			Akodon_simulator
			Akodon_spegazzinii
			Akodon_subfuscus
			Akodon_surdus
			Akodon_sylvanus
			Akodon_toba
			Akodon_torques
			Akodon_urichi
			Akodon_varius
			Akodon_xanthorhinus
			Andalgalomys_olrogi
			Andalgalomys_pearsoni
			Andinomys_edax
			Anotomys_leander
			Auliscomys_boliviensis
			Auliscomys_micropus
			Auliscomys_pictus
			Auliscomys_sublimis
			Baiomys_musculus
			Baiomys_taylori
			Bibimys_chacoensis
			Bibimys_labiosus
			Bibimys_torresi
			Blarinomys_breviceps
			Bolomys_amoenus
			Bolomys_lactens
			Bolomys_lasiurus
			Bolomys_obscurus
			Bolomys_punctulatus
			Bolomys_temchuki
			Calomys_boliviae
			Calomys_callidus
			Calomys_callosus
			Calomys_hummelincki
			Calomys_laucha
			Calomys_lepidus
			Calomys_musculinus
			Calomys_sorellus
			Calomys_tener
			Chelemys_macronyx
			Chelemys_megalonyx
			Chibchanomys_trichotis
			Chilomys_instans
			Chinchillula_sahamae
			Chroeomys_andinus
			Chroeomys_jelskii
			Delomys_dorsalis
			Delomys_sublineatus
			Eligmodontia_moreni
			Eligmodontia_morgani
			Eligmodontia_puerulus
			Eligmodontia_typus
			Euneomys_chinchilloides
			Euneomys_fossor
			Euneomys_mordax
			Euneomys_petersoni
			Galenomys_garleppi
			Geoxus_valdivianus
			Graomys_domorum
			Graomys_edithae
			Graomys_griseoflavus
			Habromys_chinanteco
			Habromys_lepturus
			Habromys_lophurus
			Habromys_simulatus
			Hodomys_alleni
			Holochilus_brasiliensis
			Holochilus_chacarius
			Holochilus_magnus
			Holochilus_sciureus
			Ichthyomys_hydrobates
			Ichthyomys_pittieri
			Ichthyomys_stolzmanni
			Ichthyomys_tweedii
			Irenomys_tarsalis
			Isthmomys_flavidus
			Isthmomys_pirrensis
			Juscelinomys_candango
			Juscelinomys_talpinus
			Kunsia_fronto
			Kunsia_tomentosus
			Lenoxus_apicalis
			Megadontomys_cryophilus
			Megadontomys_nelsoni
			Megadontomys_thomasi
			Megalomys_desmarestii
			Megalomys_luciae
			Melanomys_caliginosus
			Melanomys_robustulus
			Melanomys_zunigae
			Microryzomys_altissimus
			Microryzomys_minutus
			Neacomys_guianae
			Neacomys_pictus
			Neacomys_spinosus
			Neacomys_tenuipes
			Nectomys_palmipes
			Nectomys_parvipes
			Nectomys_squamipes
			Nelsonia_goldmani
			Nelsonia_neotomodon
			Neotoma_albigula
			Neotoma_angustapalata
			Neotoma_anthonyi
			Neotoma_bryanti
			Neotoma_bunkeri
			Neotoma_chrysomelas
			Neotoma_cinerea
			Neotoma_devia
			Neotoma_floridana
			Neotoma_fuscipes
			Neotoma_goldmani
			Neotoma_lepida
			Neotoma_martinensis
			Neotoma_mexicana
			Neotoma_micropus
			Neotoma_nelsoni
			Neotoma_palatina
			Neotoma_phenax
			Neotoma_stephensi
			Neotoma_varia
			Neotomodon_alstoni
			Neotomys_ebriosus
			Nesoryzomys_darwini
			Nesoryzomys_fernandinae
			Nesoryzomys_indefessus
			Nesoryzomys_swarthi
			Neusticomys_monticolus
			Neusticomys_mussoi
			Neusticomys_oyapocki
			Neusticomys_peruviensis
			Neusticomys_venezuelae
			Notiomys_edwardsii
			Nyctomys_sumichrasti
			Ochrotomys_nuttalli
			Oecomys_bicolor
			Oecomys_cleberi
			Oecomys_concolor
			Oecomys_flavicans
			Oecomys_mamorae
			Oecomys_paricola
			Oecomys_phaeotis
			Oecomys_rex
			Oecomys_roberti
			Oecomys_rutilus
			Oecomys_speciosus
			Oecomys_superans
			Oecomys_trinitatis
			Oligoryzomys_andinus
			Oligoryzomys_arenalis
			Oligoryzomys_chacoensis
			Oligoryzomys_delticola
			Oligoryzomys_destructor
			Oligoryzomys_eliurus
			Oligoryzomys_flavescens
			Oligoryzomys_fulvescens
			Oligoryzomys_griseolus
			Oligoryzomys_longicaudatus
			Oligoryzomys_magellanicus
			Oligoryzomys_microtis
			Oligoryzomys_nigripes
			Oligoryzomys_vegetus
			Oligoryzomys_victus
			Onychomys_arenicola
			Onychomys_leucogaster
			Onychomys_torridus
			Oryzomys_albigularis
			Oryzomys_alfaroi
			Oryzomys_auriventer
			Oryzomys_balneator
			Oryzomys_bolivaris
			Oryzomys_buccinatus
			Oryzomys_capito
			Oryzomys_chapmani
			Oryzomys_couesi
			Oryzomys_devius
			Oryzomys_dimidiatus
			Oryzomys_galapagoensis
			Oryzomys_gorgasi
			Oryzomys_hammondi
			Oryzomys_intectus
			Oryzomys_intermedius
			Oryzomys_keaysi
			Oryzomys_kelloggi
			Oryzomys_lamia
			Oryzomys_legatus
			Oryzomys_levipes
			Oryzomys_macconnelli
			Oryzomys_melanotis
			Oryzomys_nelsoni
			Oryzomys_nitidus
			Oryzomys_oniscus
			Oryzomys_palustris
			Oryzomys_polius
			Oryzomys_ratticeps
			Oryzomys_rhabdops
			Oryzomys_rostratus
			Oryzomys_saturatior
			Oryzomys_subflavus
			Oryzomys_talamancae
			Oryzomys_xantheolus
			Oryzomys_yunganus
			Osgoodomys_banderanus
			Otonyctomys_hatti
			Ototylomys_phyllotis
			Oxymycterus_akodontius
			Oxymycterus_angularis
			Oxymycterus_delator
			Oxymycterus_hiska
			Oxymycterus_hispidus
			Oxymycterus_hucucha
			Oxymycterus_iheringi
			Oxymycterus_inca
			Oxymycterus_nasutus
			Oxymycterus_paramensis
			Oxymycterus_roberti
			Oxymycterus_rufus
			Peromyscus_attwateri
			Peromyscus_aztecus
			Peromyscus_boylii
			Peromyscus_bullatus
			Peromyscus_californicus
			Peromyscus_caniceps
			Peromyscus_crinitus
			Peromyscus_dickeyi
			Peromyscus_difficilis
			Peromyscus_eremicus
			Peromyscus_eva
			Peromyscus_furvus
			Peromyscus_gossypinus
			Peromyscus_grandis
			Peromyscus_gratus
			Peromyscus_guardia
			Peromyscus_guatemalensis
			Peromyscus_gymnotis
			Peromyscus_hooperi
			Peromyscus_interparietalis
			Peromyscus_leucopus
			Peromyscus_levipes
			Peromyscus_madrensis
			Peromyscus_maniculatus
			Peromyscus_mayensis
			Peromyscus_megalops
			Peromyscus_mekisturus
			Peromyscus_melanocarpus
			Peromyscus_melanophrys
			Peromyscus_melanotis
			Peromyscus_melanurus
			Peromyscus_merriami
			Peromyscus_mexicanus
			Peromyscus_nasutus
			Peromyscus_ochraventer
			Peromyscus_oreas
			Peromyscus_pectoralis
			Peromyscus_pembertoni
			Peromyscus_perfulvus
			Peromyscus_polionotus
			Peromyscus_polius
			Peromyscus_pseudocrinitus
			Peromyscus_sejugis
			Peromyscus_simulus
			Peromyscus_sitkensis
			Peromyscus_slevini
			Peromyscus_spicilegus
			Peromyscus_stephani
			Peromyscus_stirtoni
			Peromyscus_truei
			Peromyscus_winkelmanni
			Peromyscus_yucatanicus
			Peromyscus_zarhynchus
			Phaenomys_ferrugineus
			Phyllotis_amicus
			Phyllotis_andium
			Phyllotis_bonaeriensis
			Phyllotis_caprinus
			Phyllotis_darwini
			Phyllotis_definitus
			Phyllotis_gerbillus
			Phyllotis_haggardi
			Phyllotis_magister
			Phyllotis_osgoodi
			Phyllotis_osilae
			Phyllotis_wolffsohni
			Phyllotis_xanthopygus
			Podomys_floridanus
			Podoxymys_roraimae
			Pseudoryzomys_simplex
			Punomys_lemminus
			Reithrodon_auritus
			Reithrodontomys_brevirostris
			Reithrodontomys_burti
			Reithrodontomys_chrysopsis
			Reithrodontomys_creper
			Reithrodontomys_darienensis
			Reithrodontomys_fulvescens
			Reithrodontomys_gracilis
			Reithrodontomys_hirsutus
			Reithrodontomys_humulis
			Reithrodontomys_megalotis
			Reithrodontomys_mexicanus
			Reithrodontomys_microdon
			Reithrodontomys_montanus
			Reithrodontomys_paradoxus
			Reithrodontomys_raviventris
			Reithrodontomys_rodriguezi
			Reithrodontomys_spectabilis
			Reithrodontomys_sumichrasti
			Reithrodontomys_tenuirostris
			Reithrodontomys_zacatecae
			Rhagomys_rufescens
			Rheomys_mexicanus
			Rheomys_raptor
			Rheomys_thomasi
			Rheomys_underwoodi
			Rhipidomys_austrinus
			Rhipidomys_caucensis
			Rhipidomys_couesi
			Rhipidomys_fulviventer
			Rhipidomys_latimanus
			Rhipidomys_leucodactylus
			Rhipidomys_macconnelli
			Rhipidomys_mastacalis
			Rhipidomys_nitela
			Rhipidomys_ochrogaster
			Rhipidomys_scandens
			Rhipidomys_venezuelae
			Rhipidomys_venustus
			Rhipidomys_wetzeli
			Scapteromys_tumidus
			Scolomys_melanops
			Scolomys_ucayalensis
			Scotinomys_teguina
			Scotinomys_xerampelinus
			Sigmodon_alleni
			Sigmodon_alstoni
			Sigmodon_arizonae
			Sigmodon_fulviventer
			Sigmodon_hispidus
			Sigmodon_inopinatus
			Sigmodon_leucotis
			Sigmodon_mascotensis
			Sigmodon_ochrognathus
			Sigmodon_peruanus
			Sigmodontomys_alfari
			Sigmodontomys_aphrastus
			Thalpomys_cerradensis
			Thalpomys_lasiotis
			Thomasomys_aureus
			Thomasomys_baeops
			Thomasomys_bombycinus
			Thomasomys_cinereiventer
			Thomasomys_cinereus
			Thomasomys_daphne
			Thomasomys_eleusis
			Thomasomys_gracilis
			Thomasomys_hylophilus
			Thomasomys_incanus
			Thomasomys_ischyurus
			Thomasomys_kalinowskii
			Thomasomys_ladewi
			Thomasomys_laniger
			Thomasomys_monochromos
			Thomasomys_niveipes
			Thomasomys_notatus
			Thomasomys_oreas
			Thomasomys_paramorum
			Thomasomys_pyrrhonotus
			Thomasomys_rhoadsi
			Thomasomys_rosalinda
			Thomasomys_silvestris
			Thomasomys_taczanowskii
			Thomasomys_vestitus
			Tylomys_bullaris
			Tylomys_fulviventer
			Tylomys_mirae
			Tylomys_nudicaudus
			Tylomys_panamensis
			Tylomys_tumbalensis
			Tylomys_watsoni
			Wiedomys_pyrrhorhinos
			Wilfredomys_oenax
			Wilfredomys_pictipes
			Xenomys_nelsoni
			Zygodontomys_brevicauda
			Zygodontomys_brunneus
			Nannospalax_ehrenbergi
			Nannospalax_leucodon
			Nannospalax_nehringi
			Spalax_arenarius
			Spalax_giganteus
			Spalax_graecus
			Spalax_microphthalmus
			Spalax_zemni
			Anomalurus_beecrofti
			Anomalurus_derbianus
			Anomalurus_pelii
			Anomalurus_pusillus
			Idiurus_macrotis
			Idiurus_zenkeri
			Zenkerella_insignis
			Pedetes_capensis
			Ctenodactylus_gundi
			Ctenodactylus_vali
			Felovia_vae
			Massoutiera_mzabi
			Pectinator_spekei
			Graphiurus_christyi
			Graphiurus_crassicaudatus
			Graphiurus_hueti
			Graphiurus_kelleni
			Graphiurus_lorraineus
			Graphiurus_microtis
			Graphiurus_monardi
			Graphiurus_murinus
			Graphiurus_ocularis
			Graphiurus_olga
			Graphiurus_parvus
			Graphiurus_platyops
			Graphiurus_rupicola
			Graphiurus_surdus
			Dryomys_laniger
			Dryomys_nitedula
			Dryomys_sichuanensis
			Eliomys_melanurus
			Eliomys_quercinus
			Myomimus_personatus
			Myomimus_roachi
			Myomimus_setzeri
			Selevinia_betpakdalaensis
			Glirulus_japonicus
			Muscardinus_avellanarius
			Myoxus_glis
			Bathyergus_janetta
			Bathyergus_suillus
			Cryptomys_bocagei
			Cryptomys_damarensis
			Cryptomys_foxi
			Cryptomys_hottentotus
			Cryptomys_mechowi
			Cryptomys_ochraceocinereus
			Cryptomys_zechi
			Georychus_capensis
			Heliophobius_argenteocinereus
			Heterocephalus_glaber
			Atherurus_africanus
			Atherurus_macrourus
			Hystrix_africaeaustralis
			Hystrix_brachyura
			Hystrix_crassispinis
			Hystrix_cristata
			Hystrix_indica
			Hystrix_javanica
			Hystrix_pumila
			Hystrix_sumatrae
			Trichys_fasciculata
			Petromus_typicus
			Thryonomys_gregorianus
			Thryonomys_swinderianus
			Coendou_bicolor
			Coendou_koopmani
			Coendou_prehensilis
			Coendou_rothschildi
			Echinoprocta_rufescens
			Erethizon_dorsatum
			Sphiggurus_insidiosus
			Sphiggurus_mexicanus
			Sphiggurus_pallidus
			Sphiggurus_spinosus
			Sphiggurus_vestitus
			Sphiggurus_villosus
			Chinchilla_brevicaudata
			Chinchilla_lanigera
			Lagidium_peruanum
			Lagidium_viscacia
			Lagidium_wolffsohni
			Lagostomus_maximus
			Dinomys_branickii
			Cavia_aperea
			Cavia_fulgida
			Cavia_magna
			Cavia_porcellus
			Cavia_tschudii
			Galea_flavidens
			Galea_musteloides
			Galea_spixii
			Kerodon_rupestris
			Microcavia_australis
			Microcavia_niata
			Microcavia_shiptoni
			Dolichotis_patagonum
			Dolichotis_salinicola
			Hydrochaeris_hydrochaeris
			Dasyprocta_azarae
			Dasyprocta_coibae
			Dasyprocta_cristata
			Dasyprocta_fuliginosa
			Dasyprocta_guamara
			Dasyprocta_kalinowskii
			Dasyprocta_leporina
			Dasyprocta_mexicana
			Dasyprocta_prymnolopha
			Dasyprocta_punctata
			Dasyprocta_ruatanica
			Myoprocta_acouchy
			Myoprocta_exilis
			Agouti_paca
			Agouti_taczanowskii
			Ctenomys_argentinus
			Ctenomys_australis
			Ctenomys_azarae
			Ctenomys_boliviensis
			Ctenomys_bonettoi
			Ctenomys_brasiliensis
			Ctenomys_colburni
			Ctenomys_conoveri
			Ctenomys_dorsalis
			Ctenomys_emilianus
			Ctenomys_frater
			Ctenomys_fulvus
			Ctenomys_haigi
			Ctenomys_knightii
			Ctenomys_latro
			Ctenomys_leucodon
			Ctenomys_lewisi
			Ctenomys_magellanicus
			Ctenomys_maulinus
			Ctenomys_mendocinus
			Ctenomys_minutus
			Ctenomys_nattereri
			Ctenomys_occultus
			Ctenomys_opimus
			Ctenomys_pearsoni
			Ctenomys_perrensis
			Ctenomys_peruanus
			Ctenomys_pontifex
			Ctenomys_porteousi
			Ctenomys_saltarius
			Ctenomys_sericeus
			Ctenomys_sociabilis
			Ctenomys_steinbachi
			Ctenomys_talarum
			Ctenomys_torquatus
			Ctenomys_tuconax
			Ctenomys_tucumanus
			Ctenomys_validus
			Aconaemys_fuscus
			Aconaemys_sagei
			Octodon_bridgesi
			Octodon_degus
			Octodon_lunatus
			Octodontomys_gliroides
			Octomys_mimax
			Spalacopus_cyanus
			Tympanoctomys_barrerae
			Abrocoma_bennettii
			Abrocoma_boliviensis
			Abrocoma_cinerea
			Chaetomys_subspinosus
			Dactylomys_boliviensis
			Dactylomys_dactylinus
			Dactylomys_peruanus
			Kannabateomys_amblyonyx
			Olallamys_albicauda
			Olallamys_edax
			Diplomys_caniceps
			Diplomys_labilis
			Diplomys_rufodorsalis
			Echimys_blainvillei
			Echimys_braziliensis
			Echimys_chrysurus
			Echimys_dasythrix
			Echimys_grandis
			Echimys_lamarum
			Echimys_macrurus
			Echimys_nigrispinus
			Echimys_pictus
			Echimys_rhipidurus
			Echimys_saturnus
			Echimys_semivillosus
			Echimys_thomasi
			Echimys_unicolor
			Isothrix_bistriata
			Isothrix_pagurus
			Makalata_armata
			Carterodon_sulcidens
			Clyomys_bishopi
			Clyomys_laticeps
			Euryzygomatomys_spinosus
			Hoplomys_gymnurus
			Lonchothrix_emiliae
			Mesomys_didelphoides
			Mesomys_hispidus
			Mesomys_leniceps
			Mesomys_obscurus
			Mesomys_stimulax
			Proechimys_albispinus
			Proechimys_amphichoricus
			Proechimys_bolivianus
			Proechimys_brevicauda
			Proechimys_canicollis
			Proechimys_cayennensis
			Proechimys_chrysaeolus
			Proechimys_cuvieri
			Proechimys_decumanus
			Proechimys_dimidiatus
			Proechimys_goeldii
			Proechimys_gorgonae
			Proechimys_guairae
			Proechimys_gularis
			Proechimys_hendeei
			Proechimys_hoplomyoides
			Proechimys_iheringi
			Proechimys_longicaudatus
			Proechimys_magdalenae
			Proechimys_mincae
			Proechimys_myosuros
			Proechimys_oconnelli
			Proechimys_oris
			Proechimys_poliopus
			Proechimys_quadruplicatus
			Proechimys_semispinosus
			Proechimys_setosus
			Proechimys_simonsi
			Proechimys_steerei
			Proechimys_trinitatis
			Proechimys_urichi
			Proechimys_warreni
			Thrichomys_apereoides
			Boromys_offella
			Boromys_torrei
			Brotomys_contractus
			Brotomys_voratus
			Heteropsomys_antillensis
			Heteropsomys_insulans
			Puertoricomys_corozalus
			Capromys_pilorides
			Geocapromys_brownii
			Geocapromys_ingrahami
			Geocapromys_thoracatus
			Mesocapromys_angelcabrerai
			Mesocapromys_auritus
			Mesocapromys_nanus
			Mesocapromys_sanfelipensis
			Mysateles_garridoi
			Mysateles_gundlachi
			Mysateles_melanurus
			Mysateles_meridionalis
			Mysateles_prehensilis
			Hexolobodon_phenax
			Isolobodon_montanus
			Isolobodon_portoricensis
			Plagiodontia_aedium
			Plagiodontia_araeum
			Plagiodontia_ipnaeum
			Rhizoplagiodontia_lemkei
			Clidomys_osborni
			Clidomys_parvus
			Amblyrhiza_inundata
			Elasmodontomys_obliquus
			Quemisia_gravis
			Myocastor_coypus);
		@{ $speciesList{Lagomorpha} } = qw(Ochotona_alpina
			Ochotona_cansus
			Ochotona_collaris
			Ochotona_curzoniae
			Ochotona_dauurica
			Ochotona_erythrotis
			Ochotona_forresti
			Ochotona_gaoligongensis
			Ochotona_gloveri
			Ochotona_himalayana
			Ochotona_hyperborea
			Ochotona_iliensis
			Ochotona_koslowi
			Ochotona_ladacensis
			Ochotona_macrotis
			Ochotona_muliensis
			Ochotona_nubrica
			Ochotona_pallasi
			Ochotona_princeps
			Ochotona_pusilla
			Ochotona_roylei
			Ochotona_rufescens
			Ochotona_rutila
			Ochotona_thibetana
			Ochotona_thomasi
			Prolagus_sardus
			Brachylagus_idahoensis
			Bunolagus_monticularis
			Caprolagus_hispidus
			Lepus_alleni
			Lepus_americanus
			Lepus_arcticus
			Lepus_brachyurus
			Lepus_californicus
			Lepus_callotis
			Lepus_capensis
			Lepus_castroviejoi
			Lepus_comus
			Lepus_coreanus
			Lepus_corsicanus
			Lepus_europaeus
			Lepus_fagani
			Lepus_flavigularis
			Lepus_granatensis
			Lepus_hainanus
			Lepus_insularis
			Lepus_mandshuricus
			Lepus_nigricollis
			Lepus_oiostolus
			Lepus_othus
			Lepus_peguensis
			Lepus_saxatilis
			Lepus_sinensis
			Lepus_starcki
			Lepus_timidus
			Lepus_tolai
			Lepus_townsendii
			Lepus_victoriae
			Lepus_yarkandensis
			Nesolagus_netscheri
			Oryctolagus_cuniculus
			Pentalagus_furnessi
			Poelagus_marjorita
			Pronolagus_crassicaudatus
			Pronolagus_randensis
			Pronolagus_rupestris
			Romerolagus_diazi
			Sylvilagus_aquaticus
			Sylvilagus_audubonii
			Sylvilagus_bachmani
			Sylvilagus_brasiliensis
			Sylvilagus_cunicularius
			Sylvilagus_dicei
			Sylvilagus_floridanus
			Sylvilagus_graysoni
			Sylvilagus_insonus
			Sylvilagus_mansuetus
			Sylvilagus_nuttallii
			Sylvilagus_palustris
			Sylvilagus_transitionalis);
		@{ $speciesList{Macroscelidea} } = qw(Elephantulus_brachyrhynchus
			Elephantulus_edwardii
			Elephantulus_fuscipes
			Elephantulus_fuscus
			Elephantulus_intufi
			Elephantulus_myurus
			Elephantulus_revoili
			Elephantulus_rozeti
			Elephantulus_rufescens
			Elephantulus_rupestris
			Macroscelides_proboscideus
			Petrodromus_tetradactylus
			Rhynchocyon_chrysopygus
			Rhynchocyon_cirnei
			Rhynchocyon_petersi);

	# Populate hash with species from desired orders only
		foreach my $order (@searchOrder)
			{
			if (not $orderList{$order})
				{
				print "ERROR: Order, $order, is not recognized.\n";
				}
			else
				{
				print "Loading order $order\n" if ($verbose);
				foreach my $species (@{ $speciesList{$order} })
					{
					$reftaxNames{$species} = 1;
					}
				}
			}

	my $num_keys = keys %reftaxNames;
		print "\tNumber of recognized species: $num_keys\n" if ($verbose);
		die "ERROR: No species loaded into reference taxonomy list.\n" if (not $num_keys);
	return %reftaxNames;
	}

# Version history
#
#	v2.1 (March 16, 2005)
#		- will now output only unique permutations for trees with non-monophyletic taxa
#		- added feature to autodelete unrecognized taxa
#		- added feature to use species synonym list for mammals (SpeciesSynonymID.txt; compiled by Kate Jones)
#		- minor bug fixes
#
#	v2.0.2 (July 26, 2004)
#		- minor bug fixes
#
#	v2.0.1a (April 29, 2004)
#		- added feature to automatically detect form of line breaks
#
#	v2.0.1 (March 25, 2004)
#		- corrected serious bug in permutation algorithm such that permutations are now accurate
#		  (albeit with some redundancies)
#		- added ability to restrict taxonomy to specified mammalian orders
#
#	v1.0.2 (December 16, 2002)
#		- improved taxonomy checking
#		- minor bug fixes
#
#	v1.0.1 (December 4, 2002)
#		- initial release

